import { message } from 'antd';

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

var axios$2 = {exports: {}};

var bind$2 = function bind(fn, thisArg) {
  return function wrap() {
    var args = new Array(arguments.length);

    for (var i = 0; i < args.length; i++) {
      args[i] = arguments[i];
    }

    return fn.apply(thisArg, args);
  };
};

var bind$1 = bind$2;
/*global toString:true*/
// utils is a library of generic helper functions non-specific to axios

var toString = Object.prototype.toString;
/**
 * Determine if a value is an Array
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an Array, otherwise false
 */

function isArray(val) {
  return toString.call(val) === '[object Array]';
}
/**
 * Determine if a value is undefined
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if the value is undefined, otherwise false
 */


function isUndefined(val) {
  return typeof val === 'undefined';
}
/**
 * Determine if a value is a Buffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Buffer, otherwise false
 */


function isBuffer(val) {
  return val !== null && !isUndefined(val) && val.constructor !== null && !isUndefined(val.constructor) && typeof val.constructor.isBuffer === 'function' && val.constructor.isBuffer(val);
}
/**
 * Determine if a value is an ArrayBuffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an ArrayBuffer, otherwise false
 */


function isArrayBuffer(val) {
  return toString.call(val) === '[object ArrayBuffer]';
}
/**
 * Determine if a value is a FormData
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an FormData, otherwise false
 */


function isFormData(val) {
  return typeof FormData !== 'undefined' && val instanceof FormData;
}
/**
 * Determine if a value is a view on an ArrayBuffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a view on an ArrayBuffer, otherwise false
 */


function isArrayBufferView(val) {
  var result;

  if (typeof ArrayBuffer !== 'undefined' && ArrayBuffer.isView) {
    result = ArrayBuffer.isView(val);
  } else {
    result = val && val.buffer && val.buffer instanceof ArrayBuffer;
  }

  return result;
}
/**
 * Determine if a value is a String
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a String, otherwise false
 */


function isString(val) {
  return typeof val === 'string';
}
/**
 * Determine if a value is a Number
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Number, otherwise false
 */


function isNumber(val) {
  return typeof val === 'number';
}
/**
 * Determine if a value is an Object
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an Object, otherwise false
 */


function isObject(val) {
  return val !== null && typeof val === 'object';
}
/**
 * Determine if a value is a plain Object
 *
 * @param {Object} val The value to test
 * @return {boolean} True if value is a plain Object, otherwise false
 */


function isPlainObject(val) {
  if (toString.call(val) !== '[object Object]') {
    return false;
  }

  var prototype = Object.getPrototypeOf(val);
  return prototype === null || prototype === Object.prototype;
}
/**
 * Determine if a value is a Date
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Date, otherwise false
 */


function isDate(val) {
  return toString.call(val) === '[object Date]';
}
/**
 * Determine if a value is a File
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a File, otherwise false
 */


function isFile(val) {
  return toString.call(val) === '[object File]';
}
/**
 * Determine if a value is a Blob
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Blob, otherwise false
 */


function isBlob(val) {
  return toString.call(val) === '[object Blob]';
}
/**
 * Determine if a value is a Function
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Function, otherwise false
 */


function isFunction(val) {
  return toString.call(val) === '[object Function]';
}
/**
 * Determine if a value is a Stream
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Stream, otherwise false
 */


function isStream(val) {
  return isObject(val) && isFunction(val.pipe);
}
/**
 * Determine if a value is a URLSearchParams object
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a URLSearchParams object, otherwise false
 */


function isURLSearchParams(val) {
  return typeof URLSearchParams !== 'undefined' && val instanceof URLSearchParams;
}
/**
 * Trim excess whitespace off the beginning and end of a string
 *
 * @param {String} str The String to trim
 * @returns {String} The String freed of excess whitespace
 */


function trim(str) {
  return str.replace(/^\s*/, '').replace(/\s*$/, '');
}
/**
 * Determine if we're running in a standard browser environment
 *
 * This allows axios to run in a web worker, and react-native.
 * Both environments support XMLHttpRequest, but not fully standard globals.
 *
 * web workers:
 *  typeof window -> undefined
 *  typeof document -> undefined
 *
 * react-native:
 *  navigator.product -> 'ReactNative'
 * nativescript
 *  navigator.product -> 'NativeScript' or 'NS'
 */


function isStandardBrowserEnv() {
  if (typeof navigator !== 'undefined' && (navigator.product === 'ReactNative' || navigator.product === 'NativeScript' || navigator.product === 'NS')) {
    return false;
  }

  return typeof window !== 'undefined' && typeof document !== 'undefined';
}
/**
 * Iterate over an Array or an Object invoking a function for each item.
 *
 * If `obj` is an Array callback will be called passing
 * the value, index, and complete array for each item.
 *
 * If 'obj' is an Object callback will be called passing
 * the value, key, and complete object for each property.
 *
 * @param {Object|Array} obj The object to iterate
 * @param {Function} fn The callback to invoke for each item
 */


function forEach(obj, fn) {
  // Don't bother if no value provided
  if (obj === null || typeof obj === 'undefined') {
    return;
  } // Force an array if not already something iterable


  if (typeof obj !== 'object') {
    /*eslint no-param-reassign:0*/
    obj = [obj];
  }

  if (isArray(obj)) {
    // Iterate over array values
    for (var i = 0, l = obj.length; i < l; i++) {
      fn.call(null, obj[i], i, obj);
    }
  } else {
    // Iterate over object keys
    for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        fn.call(null, obj[key], key, obj);
      }
    }
  }
}
/**
 * Accepts varargs expecting each argument to be an object, then
 * immutably merges the properties of each object and returns result.
 *
 * When multiple objects contain the same key the later object in
 * the arguments list will take precedence.
 *
 * Example:
 *
 * ```js
 * var result = merge({foo: 123}, {foo: 456});
 * console.log(result.foo); // outputs 456
 * ```
 *
 * @param {Object} obj1 Object to merge
 * @returns {Object} Result of all merge properties
 */


function merge()
/* obj1, obj2, obj3, ... */
{
  var result = {};

  function assignValue(val, key) {
    if (isPlainObject(result[key]) && isPlainObject(val)) {
      result[key] = merge(result[key], val);
    } else if (isPlainObject(val)) {
      result[key] = merge({}, val);
    } else if (isArray(val)) {
      result[key] = val.slice();
    } else {
      result[key] = val;
    }
  }

  for (var i = 0, l = arguments.length; i < l; i++) {
    forEach(arguments[i], assignValue);
  }

  return result;
}
/**
 * Extends object a by mutably adding to it the properties of object b.
 *
 * @param {Object} a The object to be extended
 * @param {Object} b The object to copy properties from
 * @param {Object} thisArg The object to bind function to
 * @return {Object} The resulting value of object a
 */


function extend(a, b, thisArg) {
  forEach(b, function assignValue(val, key) {
    if (thisArg && typeof val === 'function') {
      a[key] = bind$1(val, thisArg);
    } else {
      a[key] = val;
    }
  });
  return a;
}
/**
 * Remove byte order marker. This catches EF BB BF (the UTF-8 BOM)
 *
 * @param {string} content with BOM
 * @return {string} content value without BOM
 */


function stripBOM(content) {
  if (content.charCodeAt(0) === 0xFEFF) {
    content = content.slice(1);
  }

  return content;
}

var utils$d = {
  isArray: isArray,
  isArrayBuffer: isArrayBuffer,
  isBuffer: isBuffer,
  isFormData: isFormData,
  isArrayBufferView: isArrayBufferView,
  isString: isString,
  isNumber: isNumber,
  isObject: isObject,
  isPlainObject: isPlainObject,
  isUndefined: isUndefined,
  isDate: isDate,
  isFile: isFile,
  isBlob: isBlob,
  isFunction: isFunction,
  isStream: isStream,
  isURLSearchParams: isURLSearchParams,
  isStandardBrowserEnv: isStandardBrowserEnv,
  forEach: forEach,
  merge: merge,
  extend: extend,
  trim: trim,
  stripBOM: stripBOM
};

var utils$c = utils$d;

function encode(val) {
  return encodeURIComponent(val).replace(/%3A/gi, ':').replace(/%24/g, '$').replace(/%2C/gi, ',').replace(/%20/g, '+').replace(/%5B/gi, '[').replace(/%5D/gi, ']');
}
/**
 * Build a URL by appending params to the end
 *
 * @param {string} url The base of the url (e.g., http://www.google.com)
 * @param {object} [params] The params to be appended
 * @returns {string} The formatted url
 */


var buildURL$2 = function buildURL(url, params, paramsSerializer) {
  /*eslint no-param-reassign:0*/
  if (!params) {
    return url;
  }

  var serializedParams;

  if (paramsSerializer) {
    serializedParams = paramsSerializer(params);
  } else if (utils$c.isURLSearchParams(params)) {
    serializedParams = params.toString();
  } else {
    var parts = [];
    utils$c.forEach(params, function serialize(val, key) {
      if (val === null || typeof val === 'undefined') {
        return;
      }

      if (utils$c.isArray(val)) {
        key = key + '[]';
      } else {
        val = [val];
      }

      utils$c.forEach(val, function parseValue(v) {
        if (utils$c.isDate(v)) {
          v = v.toISOString();
        } else if (utils$c.isObject(v)) {
          v = JSON.stringify(v);
        }

        parts.push(encode(key) + '=' + encode(v));
      });
    });
    serializedParams = parts.join('&');
  }

  if (serializedParams) {
    var hashmarkIndex = url.indexOf('#');

    if (hashmarkIndex !== -1) {
      url = url.slice(0, hashmarkIndex);
    }

    url += (url.indexOf('?') === -1 ? '?' : '&') + serializedParams;
  }

  return url;
};

var utils$b = utils$d;

function InterceptorManager$1() {
  this.handlers = [];
}
/**
 * Add a new interceptor to the stack
 *
 * @param {Function} fulfilled The function to handle `then` for a `Promise`
 * @param {Function} rejected The function to handle `reject` for a `Promise`
 *
 * @return {Number} An ID used to remove interceptor later
 */


InterceptorManager$1.prototype.use = function use(fulfilled, rejected) {
  this.handlers.push({
    fulfilled: fulfilled,
    rejected: rejected
  });
  return this.handlers.length - 1;
};
/**
 * Remove an interceptor from the stack
 *
 * @param {Number} id The ID that was returned by `use`
 */


InterceptorManager$1.prototype.eject = function eject(id) {
  if (this.handlers[id]) {
    this.handlers[id] = null;
  }
};
/**
 * Iterate over all the registered interceptors
 *
 * This method is particularly useful for skipping over any
 * interceptors that may have become `null` calling `eject`.
 *
 * @param {Function} fn The function to call for each interceptor
 */


InterceptorManager$1.prototype.forEach = function forEach(fn) {
  utils$b.forEach(this.handlers, function forEachHandler(h) {
    if (h !== null) {
      fn(h);
    }
  });
};

var InterceptorManager_1 = InterceptorManager$1;

var utils$a = utils$d;
/**
 * Transform the data for a request or a response
 *
 * @param {Object|String} data The data to be transformed
 * @param {Array} headers The headers for the request or response
 * @param {Array|Function} fns A single function or Array of functions
 * @returns {*} The resulting transformed data
 */

var transformData$1 = function transformData(data, headers, fns) {
  /*eslint no-param-reassign:0*/
  utils$a.forEach(fns, function transform(fn) {
    data = fn(data, headers);
  });
  return data;
};

var isCancel$1 = function isCancel(value) {
  return !!(value && value.__CANCEL__);
};

var utils$9 = utils$d;

var normalizeHeaderName$1 = function normalizeHeaderName(headers, normalizedName) {
  utils$9.forEach(headers, function processHeader(value, name) {
    if (name !== normalizedName && name.toUpperCase() === normalizedName.toUpperCase()) {
      headers[normalizedName] = value;
      delete headers[name];
    }
  });
};

/**
 * Update an Error with the specified config, error code, and response.
 *
 * @param {Error} error The error to update.
 * @param {Object} config The config.
 * @param {string} [code] The error code (for example, 'ECONNABORTED').
 * @param {Object} [request] The request.
 * @param {Object} [response] The response.
 * @returns {Error} The error.
 */


var enhanceError$1 = function enhanceError(error, config, code, request, response) {
  error.config = config;

  if (code) {
    error.code = code;
  }

  error.request = request;
  error.response = response;
  error.isAxiosError = true;

  error.toJSON = function toJSON() {
    return {
      // Standard
      message: this.message,
      name: this.name,
      // Microsoft
      description: this.description,
      number: this.number,
      // Mozilla
      fileName: this.fileName,
      lineNumber: this.lineNumber,
      columnNumber: this.columnNumber,
      stack: this.stack,
      // Axios
      config: this.config,
      code: this.code
    };
  };

  return error;
};

var enhanceError = enhanceError$1;
/**
 * Create an Error with the specified message, config, error code, request and response.
 *
 * @param {string} message The error message.
 * @param {Object} config The config.
 * @param {string} [code] The error code (for example, 'ECONNABORTED').
 * @param {Object} [request] The request.
 * @param {Object} [response] The response.
 * @returns {Error} The created error.
 */

var createError$2 = function createError(message, config, code, request, response) {
  var error = new Error(message);
  return enhanceError(error, config, code, request, response);
};

var createError$1 = createError$2;
/**
 * Resolve or reject a Promise based on response status.
 *
 * @param {Function} resolve A function that resolves the promise.
 * @param {Function} reject A function that rejects the promise.
 * @param {object} response The response.
 */

var settle$1 = function settle(resolve, reject, response) {
  var validateStatus = response.config.validateStatus;

  if (!response.status || !validateStatus || validateStatus(response.status)) {
    resolve(response);
  } else {
    reject(createError$1('Request failed with status code ' + response.status, response.config, null, response.request, response));
  }
};

var utils$8 = utils$d;
var cookies$1 = utils$8.isStandardBrowserEnv() ? // Standard browser envs support document.cookie
function standardBrowserEnv() {
  return {
    write: function write(name, value, expires, path, domain, secure) {
      var cookie = [];
      cookie.push(name + '=' + encodeURIComponent(value));

      if (utils$8.isNumber(expires)) {
        cookie.push('expires=' + new Date(expires).toGMTString());
      }

      if (utils$8.isString(path)) {
        cookie.push('path=' + path);
      }

      if (utils$8.isString(domain)) {
        cookie.push('domain=' + domain);
      }

      if (secure === true) {
        cookie.push('secure');
      }

      document.cookie = cookie.join('; ');
    },
    read: function read(name) {
      var match = document.cookie.match(new RegExp('(^|;\\s*)(' + name + ')=([^;]*)'));
      return match ? decodeURIComponent(match[3]) : null;
    },
    remove: function remove(name) {
      this.write(name, '', Date.now() - 86400000);
    }
  };
}() : // Non standard browser env (web workers, react-native) lack needed support.
function nonStandardBrowserEnv() {
  return {
    write: function write() {},
    read: function read() {
      return null;
    },
    remove: function remove() {}
  };
}();

/**
 * Determines whether the specified URL is absolute
 *
 * @param {string} url The URL to test
 * @returns {boolean} True if the specified URL is absolute, otherwise false
 */


var isAbsoluteURL$1 = function isAbsoluteURL(url) {
  // A URL is considered absolute if it begins with "<scheme>://" or "//" (protocol-relative URL).
  // RFC 3986 defines scheme name as a sequence of characters beginning with a letter and followed
  // by any combination of letters, digits, plus, period, or hyphen.
  return /^([a-z][a-z\d\+\-\.]*:)?\/\//i.test(url);
};

/**
 * Creates a new URL by combining the specified URLs
 *
 * @param {string} baseURL The base URL
 * @param {string} relativeURL The relative URL
 * @returns {string} The combined URL
 */


var combineURLs$1 = function combineURLs(baseURL, relativeURL) {
  return relativeURL ? baseURL.replace(/\/+$/, '') + '/' + relativeURL.replace(/^\/+/, '') : baseURL;
};

var isAbsoluteURL = isAbsoluteURL$1;
var combineURLs = combineURLs$1;
/**
 * Creates a new URL by combining the baseURL with the requestedURL,
 * only when the requestedURL is not already an absolute URL.
 * If the requestURL is absolute, this function returns the requestedURL untouched.
 *
 * @param {string} baseURL The base URL
 * @param {string} requestedURL Absolute or relative URL to combine
 * @returns {string} The combined full path
 */

var buildFullPath$1 = function buildFullPath(baseURL, requestedURL) {
  if (baseURL && !isAbsoluteURL(requestedURL)) {
    return combineURLs(baseURL, requestedURL);
  }

  return requestedURL;
};

var utils$7 = utils$d; // Headers whose duplicates are ignored by node
// c.f. https://nodejs.org/api/http.html#http_message_headers

var ignoreDuplicateOf = ['age', 'authorization', 'content-length', 'content-type', 'etag', 'expires', 'from', 'host', 'if-modified-since', 'if-unmodified-since', 'last-modified', 'location', 'max-forwards', 'proxy-authorization', 'referer', 'retry-after', 'user-agent'];
/**
 * Parse headers into an object
 *
 * ```
 * Date: Wed, 27 Aug 2014 08:58:49 GMT
 * Content-Type: application/json
 * Connection: keep-alive
 * Transfer-Encoding: chunked
 * ```
 *
 * @param {String} headers Headers needing to be parsed
 * @returns {Object} Headers parsed into an object
 */

var parseHeaders$1 = function parseHeaders(headers) {
  var parsed = {};
  var key;
  var val;
  var i;

  if (!headers) {
    return parsed;
  }

  utils$7.forEach(headers.split('\n'), function parser(line) {
    i = line.indexOf(':');
    key = utils$7.trim(line.substr(0, i)).toLowerCase();
    val = utils$7.trim(line.substr(i + 1));

    if (key) {
      if (parsed[key] && ignoreDuplicateOf.indexOf(key) >= 0) {
        return;
      }

      if (key === 'set-cookie') {
        parsed[key] = (parsed[key] ? parsed[key] : []).concat([val]);
      } else {
        parsed[key] = parsed[key] ? parsed[key] + ', ' + val : val;
      }
    }
  });
  return parsed;
};

var utils$6 = utils$d;
var isURLSameOrigin$1 = utils$6.isStandardBrowserEnv() ? // Standard browser envs have full support of the APIs needed to test
// whether the request URL is of the same origin as current location.
function standardBrowserEnv() {
  var msie = /(msie|trident)/i.test(navigator.userAgent);
  var urlParsingNode = document.createElement('a');
  var originURL;
  /**
  * Parse a URL to discover it's components
  *
  * @param {String} url The URL to be parsed
  * @returns {Object}
  */

  function resolveURL(url) {
    var href = url;

    if (msie) {
      // IE needs attribute set twice to normalize properties
      urlParsingNode.setAttribute('href', href);
      href = urlParsingNode.href;
    }

    urlParsingNode.setAttribute('href', href); // urlParsingNode provides the UrlUtils interface - http://url.spec.whatwg.org/#urlutils

    return {
      href: urlParsingNode.href,
      protocol: urlParsingNode.protocol ? urlParsingNode.protocol.replace(/:$/, '') : '',
      host: urlParsingNode.host,
      search: urlParsingNode.search ? urlParsingNode.search.replace(/^\?/, '') : '',
      hash: urlParsingNode.hash ? urlParsingNode.hash.replace(/^#/, '') : '',
      hostname: urlParsingNode.hostname,
      port: urlParsingNode.port,
      pathname: urlParsingNode.pathname.charAt(0) === '/' ? urlParsingNode.pathname : '/' + urlParsingNode.pathname
    };
  }

  originURL = resolveURL(window.location.href);
  /**
  * Determine if a URL shares the same origin as the current location
  *
  * @param {String} requestURL The URL to test
  * @returns {boolean} True if URL shares the same origin, otherwise false
  */

  return function isURLSameOrigin(requestURL) {
    var parsed = utils$6.isString(requestURL) ? resolveURL(requestURL) : requestURL;
    return parsed.protocol === originURL.protocol && parsed.host === originURL.host;
  };
}() : // Non standard browser envs (web workers, react-native) lack needed support.
function nonStandardBrowserEnv() {
  return function isURLSameOrigin() {
    return true;
  };
}();

var utils$5 = utils$d;
var settle = settle$1;
var cookies = cookies$1;
var buildURL$1 = buildURL$2;
var buildFullPath = buildFullPath$1;
var parseHeaders = parseHeaders$1;
var isURLSameOrigin = isURLSameOrigin$1;
var createError = createError$2;

var xhr = function xhrAdapter(config) {
  return new Promise(function dispatchXhrRequest(resolve, reject) {
    var requestData = config.data;
    var requestHeaders = config.headers;

    if (utils$5.isFormData(requestData)) {
      delete requestHeaders['Content-Type']; // Let the browser set it
    }

    var request = new XMLHttpRequest(); // HTTP basic authentication

    if (config.auth) {
      var username = config.auth.username || '';
      var password = config.auth.password ? unescape(encodeURIComponent(config.auth.password)) : '';
      requestHeaders.Authorization = 'Basic ' + btoa(username + ':' + password);
    }

    var fullPath = buildFullPath(config.baseURL, config.url);
    request.open(config.method.toUpperCase(), buildURL$1(fullPath, config.params, config.paramsSerializer), true); // Set the request timeout in MS

    request.timeout = config.timeout; // Listen for ready state

    request.onreadystatechange = function handleLoad() {
      if (!request || request.readyState !== 4) {
        return;
      } // The request errored out and we didn't get a response, this will be
      // handled by onerror instead
      // With one exception: request that using file: protocol, most browsers
      // will return status as 0 even though it's a successful request


      if (request.status === 0 && !(request.responseURL && request.responseURL.indexOf('file:') === 0)) {
        return;
      } // Prepare the response


      var responseHeaders = 'getAllResponseHeaders' in request ? parseHeaders(request.getAllResponseHeaders()) : null;
      var responseData = !config.responseType || config.responseType === 'text' ? request.responseText : request.response;
      var response = {
        data: responseData,
        status: request.status,
        statusText: request.statusText,
        headers: responseHeaders,
        config: config,
        request: request
      };
      settle(resolve, reject, response); // Clean up request

      request = null;
    }; // Handle browser request cancellation (as opposed to a manual cancellation)


    request.onabort = function handleAbort() {
      if (!request) {
        return;
      }

      reject(createError('Request aborted', config, 'ECONNABORTED', request)); // Clean up request

      request = null;
    }; // Handle low level network errors


    request.onerror = function handleError() {
      // Real errors are hidden from us by the browser
      // onerror should only fire if it's a network error
      reject(createError('Network Error', config, null, request)); // Clean up request

      request = null;
    }; // Handle timeout


    request.ontimeout = function handleTimeout() {
      var timeoutErrorMessage = 'timeout of ' + config.timeout + 'ms exceeded';

      if (config.timeoutErrorMessage) {
        timeoutErrorMessage = config.timeoutErrorMessage;
      }

      reject(createError(timeoutErrorMessage, config, 'ECONNABORTED', request)); // Clean up request

      request = null;
    }; // Add xsrf header
    // This is only done if running in a standard browser environment.
    // Specifically not if we're in a web worker, or react-native.


    if (utils$5.isStandardBrowserEnv()) {
      // Add xsrf header
      var xsrfValue = (config.withCredentials || isURLSameOrigin(fullPath)) && config.xsrfCookieName ? cookies.read(config.xsrfCookieName) : undefined;

      if (xsrfValue) {
        requestHeaders[config.xsrfHeaderName] = xsrfValue;
      }
    } // Add headers to the request


    if ('setRequestHeader' in request) {
      utils$5.forEach(requestHeaders, function setRequestHeader(val, key) {
        if (typeof requestData === 'undefined' && key.toLowerCase() === 'content-type') {
          // Remove Content-Type if data is undefined
          delete requestHeaders[key];
        } else {
          // Otherwise add header to the request
          request.setRequestHeader(key, val);
        }
      });
    } // Add withCredentials to request if needed


    if (!utils$5.isUndefined(config.withCredentials)) {
      request.withCredentials = !!config.withCredentials;
    } // Add responseType to request if needed


    if (config.responseType) {
      try {
        request.responseType = config.responseType;
      } catch (e) {
        // Expected DOMException thrown by browsers not compatible XMLHttpRequest Level 2.
        // But, this can be suppressed for 'json' type as it can be parsed by default 'transformResponse' function.
        if (config.responseType !== 'json') {
          throw e;
        }
      }
    } // Handle progress if needed


    if (typeof config.onDownloadProgress === 'function') {
      request.addEventListener('progress', config.onDownloadProgress);
    } // Not all browsers support upload events


    if (typeof config.onUploadProgress === 'function' && request.upload) {
      request.upload.addEventListener('progress', config.onUploadProgress);
    }

    if (config.cancelToken) {
      // Handle cancellation
      config.cancelToken.promise.then(function onCanceled(cancel) {
        if (!request) {
          return;
        }

        request.abort();
        reject(cancel); // Clean up request

        request = null;
      });
    }

    if (!requestData) {
      requestData = null;
    } // Send the request


    request.send(requestData);
  });
};

var utils$4 = utils$d;
var normalizeHeaderName = normalizeHeaderName$1;
var DEFAULT_CONTENT_TYPE = {
  'Content-Type': 'application/x-www-form-urlencoded'
};

function setContentTypeIfUnset(headers, value) {
  if (!utils$4.isUndefined(headers) && utils$4.isUndefined(headers['Content-Type'])) {
    headers['Content-Type'] = value;
  }
}

function getDefaultAdapter() {
  var adapter;

  if (typeof XMLHttpRequest !== 'undefined') {
    // For browsers use XHR adapter
    adapter = xhr;
  } else if (typeof process !== 'undefined' && Object.prototype.toString.call(process) === '[object process]') {
    // For node use HTTP adapter
    adapter = xhr;
  }

  return adapter;
}

var defaults$2 = {
  adapter: getDefaultAdapter(),
  transformRequest: [function transformRequest(data, headers) {
    normalizeHeaderName(headers, 'Accept');
    normalizeHeaderName(headers, 'Content-Type');

    if (utils$4.isFormData(data) || utils$4.isArrayBuffer(data) || utils$4.isBuffer(data) || utils$4.isStream(data) || utils$4.isFile(data) || utils$4.isBlob(data)) {
      return data;
    }

    if (utils$4.isArrayBufferView(data)) {
      return data.buffer;
    }

    if (utils$4.isURLSearchParams(data)) {
      setContentTypeIfUnset(headers, 'application/x-www-form-urlencoded;charset=utf-8');
      return data.toString();
    }

    if (utils$4.isObject(data)) {
      setContentTypeIfUnset(headers, 'application/json;charset=utf-8');
      return JSON.stringify(data);
    }

    return data;
  }],
  transformResponse: [function transformResponse(data) {
    /*eslint no-param-reassign:0*/
    if (typeof data === 'string') {
      try {
        data = JSON.parse(data);
      } catch (e) {
        /* Ignore */
      }
    }

    return data;
  }],

  /**
   * A timeout in milliseconds to abort a request. If set to 0 (default) a
   * timeout is not created.
   */
  timeout: 0,
  xsrfCookieName: 'XSRF-TOKEN',
  xsrfHeaderName: 'X-XSRF-TOKEN',
  maxContentLength: -1,
  maxBodyLength: -1,
  validateStatus: function validateStatus(status) {
    return status >= 200 && status < 300;
  }
};
defaults$2.headers = {
  common: {
    'Accept': 'application/json, text/plain, */*'
  }
};
utils$4.forEach(['delete', 'get', 'head'], function forEachMethodNoData(method) {
  defaults$2.headers[method] = {};
});
utils$4.forEach(['post', 'put', 'patch'], function forEachMethodWithData(method) {
  defaults$2.headers[method] = utils$4.merge(DEFAULT_CONTENT_TYPE);
});
var defaults_1 = defaults$2;

var utils$3 = utils$d;
var transformData = transformData$1;
var isCancel = isCancel$1;
var defaults$1 = defaults_1;
/**
 * Throws a `Cancel` if cancellation has been requested.
 */

function throwIfCancellationRequested(config) {
  if (config.cancelToken) {
    config.cancelToken.throwIfRequested();
  }
}
/**
 * Dispatch a request to the server using the configured adapter.
 *
 * @param {object} config The config that is to be used for the request
 * @returns {Promise} The Promise to be fulfilled
 */


var dispatchRequest$1 = function dispatchRequest(config) {
  throwIfCancellationRequested(config); // Ensure headers exist

  config.headers = config.headers || {}; // Transform request data

  config.data = transformData(config.data, config.headers, config.transformRequest); // Flatten headers

  config.headers = utils$3.merge(config.headers.common || {}, config.headers[config.method] || {}, config.headers);
  utils$3.forEach(['delete', 'get', 'head', 'post', 'put', 'patch', 'common'], function cleanHeaderConfig(method) {
    delete config.headers[method];
  });
  var adapter = config.adapter || defaults$1.adapter;
  return adapter(config).then(function onAdapterResolution(response) {
    throwIfCancellationRequested(config); // Transform response data

    response.data = transformData(response.data, response.headers, config.transformResponse);
    return response;
  }, function onAdapterRejection(reason) {
    if (!isCancel(reason)) {
      throwIfCancellationRequested(config); // Transform response data

      if (reason && reason.response) {
        reason.response.data = transformData(reason.response.data, reason.response.headers, config.transformResponse);
      }
    }

    return Promise.reject(reason);
  });
};

var utils$2 = utils$d;
/**
 * Config-specific merge-function which creates a new config-object
 * by merging two configuration objects together.
 *
 * @param {Object} config1
 * @param {Object} config2
 * @returns {Object} New object resulting from merging config2 to config1
 */

var mergeConfig$2 = function mergeConfig(config1, config2) {
  // eslint-disable-next-line no-param-reassign
  config2 = config2 || {};
  var config = {};
  var valueFromConfig2Keys = ['url', 'method', 'data'];
  var mergeDeepPropertiesKeys = ['headers', 'auth', 'proxy', 'params'];
  var defaultToConfig2Keys = ['baseURL', 'transformRequest', 'transformResponse', 'paramsSerializer', 'timeout', 'timeoutMessage', 'withCredentials', 'adapter', 'responseType', 'xsrfCookieName', 'xsrfHeaderName', 'onUploadProgress', 'onDownloadProgress', 'decompress', 'maxContentLength', 'maxBodyLength', 'maxRedirects', 'transport', 'httpAgent', 'httpsAgent', 'cancelToken', 'socketPath', 'responseEncoding'];
  var directMergeKeys = ['validateStatus'];

  function getMergedValue(target, source) {
    if (utils$2.isPlainObject(target) && utils$2.isPlainObject(source)) {
      return utils$2.merge(target, source);
    } else if (utils$2.isPlainObject(source)) {
      return utils$2.merge({}, source);
    } else if (utils$2.isArray(source)) {
      return source.slice();
    }

    return source;
  }

  function mergeDeepProperties(prop) {
    if (!utils$2.isUndefined(config2[prop])) {
      config[prop] = getMergedValue(config1[prop], config2[prop]);
    } else if (!utils$2.isUndefined(config1[prop])) {
      config[prop] = getMergedValue(undefined, config1[prop]);
    }
  }

  utils$2.forEach(valueFromConfig2Keys, function valueFromConfig2(prop) {
    if (!utils$2.isUndefined(config2[prop])) {
      config[prop] = getMergedValue(undefined, config2[prop]);
    }
  });
  utils$2.forEach(mergeDeepPropertiesKeys, mergeDeepProperties);
  utils$2.forEach(defaultToConfig2Keys, function defaultToConfig2(prop) {
    if (!utils$2.isUndefined(config2[prop])) {
      config[prop] = getMergedValue(undefined, config2[prop]);
    } else if (!utils$2.isUndefined(config1[prop])) {
      config[prop] = getMergedValue(undefined, config1[prop]);
    }
  });
  utils$2.forEach(directMergeKeys, function merge(prop) {
    if (prop in config2) {
      config[prop] = getMergedValue(config1[prop], config2[prop]);
    } else if (prop in config1) {
      config[prop] = getMergedValue(undefined, config1[prop]);
    }
  });
  var axiosKeys = valueFromConfig2Keys.concat(mergeDeepPropertiesKeys).concat(defaultToConfig2Keys).concat(directMergeKeys);
  var otherKeys = Object.keys(config1).concat(Object.keys(config2)).filter(function filterAxiosKeys(key) {
    return axiosKeys.indexOf(key) === -1;
  });
  utils$2.forEach(otherKeys, mergeDeepProperties);
  return config;
};

var utils$1 = utils$d;
var buildURL = buildURL$2;
var InterceptorManager = InterceptorManager_1;
var dispatchRequest = dispatchRequest$1;
var mergeConfig$1 = mergeConfig$2;
/**
 * Create a new instance of Axios
 *
 * @param {Object} instanceConfig The default config for the instance
 */

function Axios$1(instanceConfig) {
  this.defaults = instanceConfig;
  this.interceptors = {
    request: new InterceptorManager(),
    response: new InterceptorManager()
  };
}
/**
 * Dispatch a request
 *
 * @param {Object} config The config specific for this request (merged with this.defaults)
 */


Axios$1.prototype.request = function request(config) {
  /*eslint no-param-reassign:0*/
  // Allow for axios('example/url'[, config]) a la fetch API
  if (typeof config === 'string') {
    config = arguments[1] || {};
    config.url = arguments[0];
  } else {
    config = config || {};
  }

  config = mergeConfig$1(this.defaults, config); // Set config.method

  if (config.method) {
    config.method = config.method.toLowerCase();
  } else if (this.defaults.method) {
    config.method = this.defaults.method.toLowerCase();
  } else {
    config.method = 'get';
  } // Hook up interceptors middleware


  var chain = [dispatchRequest, undefined];
  var promise = Promise.resolve(config);
  this.interceptors.request.forEach(function unshiftRequestInterceptors(interceptor) {
    chain.unshift(interceptor.fulfilled, interceptor.rejected);
  });
  this.interceptors.response.forEach(function pushResponseInterceptors(interceptor) {
    chain.push(interceptor.fulfilled, interceptor.rejected);
  });

  while (chain.length) {
    promise = promise.then(chain.shift(), chain.shift());
  }

  return promise;
};

Axios$1.prototype.getUri = function getUri(config) {
  config = mergeConfig$1(this.defaults, config);
  return buildURL(config.url, config.params, config.paramsSerializer).replace(/^\?/, '');
}; // Provide aliases for supported request methods


utils$1.forEach(['delete', 'get', 'head', 'options'], function forEachMethodNoData(method) {
  /*eslint func-names:0*/
  Axios$1.prototype[method] = function (url, config) {
    return this.request(mergeConfig$1(config || {}, {
      method: method,
      url: url,
      data: (config || {}).data
    }));
  };
});
utils$1.forEach(['post', 'put', 'patch'], function forEachMethodWithData(method) {
  /*eslint func-names:0*/
  Axios$1.prototype[method] = function (url, data, config) {
    return this.request(mergeConfig$1(config || {}, {
      method: method,
      url: url,
      data: data
    }));
  };
});
var Axios_1 = Axios$1;

/**
 * A `Cancel` is an object that is thrown when an operation is canceled.
 *
 * @class
 * @param {string=} message The message.
 */


function Cancel$1(message) {
  this.message = message;
}

Cancel$1.prototype.toString = function toString() {
  return 'Cancel' + (this.message ? ': ' + this.message : '');
};

Cancel$1.prototype.__CANCEL__ = true;
var Cancel_1 = Cancel$1;

var Cancel = Cancel_1;
/**
 * A `CancelToken` is an object that can be used to request cancellation of an operation.
 *
 * @class
 * @param {Function} executor The executor function.
 */

function CancelToken(executor) {
  if (typeof executor !== 'function') {
    throw new TypeError('executor must be a function.');
  }

  var resolvePromise;
  this.promise = new Promise(function promiseExecutor(resolve) {
    resolvePromise = resolve;
  });
  var token = this;
  executor(function cancel(message) {
    if (token.reason) {
      // Cancellation has already been requested
      return;
    }

    token.reason = new Cancel(message);
    resolvePromise(token.reason);
  });
}
/**
 * Throws a `Cancel` if cancellation has been requested.
 */


CancelToken.prototype.throwIfRequested = function throwIfRequested() {
  if (this.reason) {
    throw this.reason;
  }
};
/**
 * Returns an object that contains a new `CancelToken` and a function that, when called,
 * cancels the `CancelToken`.
 */


CancelToken.source = function source() {
  var cancel;
  var token = new CancelToken(function executor(c) {
    cancel = c;
  });
  return {
    token: token,
    cancel: cancel
  };
};

var CancelToken_1 = CancelToken;

/**
 * Syntactic sugar for invoking a function and expanding an array for arguments.
 *
 * Common use case would be to use `Function.prototype.apply`.
 *
 *  ```js
 *  function f(x, y, z) {}
 *  var args = [1, 2, 3];
 *  f.apply(null, args);
 *  ```
 *
 * With `spread` this example can be re-written.
 *
 *  ```js
 *  spread(function(x, y, z) {})([1, 2, 3]);
 *  ```
 *
 * @param {Function} callback
 * @returns {Function}
 */


var spread = function spread(callback) {
  return function wrap(arr) {
    return callback.apply(null, arr);
  };
};

/**
 * Determines whether the payload is an error thrown by Axios
 *
 * @param {*} payload The value to test
 * @returns {boolean} True if the payload is an error thrown by Axios, otherwise false
 */


var isAxiosError = function isAxiosError(payload) {
  return typeof payload === 'object' && payload.isAxiosError === true;
};

var utils = utils$d;
var bind = bind$2;
var Axios = Axios_1;
var mergeConfig = mergeConfig$2;
var defaults = defaults_1;
/**
 * Create an instance of Axios
 *
 * @param {Object} defaultConfig The default config for the instance
 * @return {Axios} A new instance of Axios
 */

function createInstance(defaultConfig) {
  var context = new Axios(defaultConfig);
  var instance = bind(Axios.prototype.request, context); // Copy axios.prototype to instance

  utils.extend(instance, Axios.prototype, context); // Copy context to instance

  utils.extend(instance, context);
  return instance;
} // Create the default instance to be exported


var axios$1 = createInstance(defaults); // Expose Axios class to allow class inheritance

axios$1.Axios = Axios; // Factory for creating new instances

axios$1.create = function create(instanceConfig) {
  return createInstance(mergeConfig(axios$1.defaults, instanceConfig));
}; // Expose Cancel & CancelToken


axios$1.Cancel = Cancel_1;
axios$1.CancelToken = CancelToken_1;
axios$1.isCancel = isCancel$1; // Expose all/spread

axios$1.all = function all(promises) {
  return Promise.all(promises);
};

axios$1.spread = spread; // Expose isAxiosError

axios$1.isAxiosError = isAxiosError;
axios$2.exports = axios$1; // Allow use of default import syntax in TypeScript

axios$2.exports.default = axios$1;

var axios = axios$2.exports;

var ywfeUtils_umd = {exports: {}};

(function (module, exports) {
  !function (e, t) {
    t(exports) ;
  }(commonjsGlobal, function (e) {

    function t(e) {
      return null != e && "object" == typeof e && !0 === e["@@functional/placeholder"];
    }

    function n(e) {
      return function n(r) {
        return 0 === arguments.length || t(r) ? n : e.apply(this, arguments);
      };
    }

    function r(e) {
      return function r(o, u) {
        switch (arguments.length) {
          case 0:
            return r;

          case 1:
            return t(o) ? r : n(function (t) {
              return e(o, t);
            });

          default:
            return t(o) && t(u) ? r : t(o) ? n(function (t) {
              return e(t, u);
            }) : t(u) ? n(function (t) {
              return e(o, t);
            }) : e(o, u);
        }
      };
    }

    function o(e, t) {
      switch (e) {
        case 0:
          return function () {
            return t.apply(this, arguments);
          };

        case 1:
          return function (e) {
            return t.apply(this, arguments);
          };

        case 2:
          return function (e, n) {
            return t.apply(this, arguments);
          };

        case 3:
          return function (e, n, r) {
            return t.apply(this, arguments);
          };

        case 4:
          return function (e, n, r, o) {
            return t.apply(this, arguments);
          };

        case 5:
          return function (e, n, r, o, u) {
            return t.apply(this, arguments);
          };

        case 6:
          return function (e, n, r, o, u, i) {
            return t.apply(this, arguments);
          };

        case 7:
          return function (e, n, r, o, u, i, c) {
            return t.apply(this, arguments);
          };

        case 8:
          return function (e, n, r, o, u, i, c, a) {
            return t.apply(this, arguments);
          };

        case 9:
          return function (e, n, r, o, u, i, c, a, s) {
            return t.apply(this, arguments);
          };

        case 10:
          return function (e, n, r, o, u, i, c, a, s, f) {
            return t.apply(this, arguments);
          };

        default:
          throw new Error("First argument to _arity must be a non-negative integer no greater than ten");
      }
    }

    function u(e, n, r) {
      return function () {
        for (var i = [], c = 0, a = e, s = 0; s < n.length || c < arguments.length;) {
          var f;
          s < n.length && (!t(n[s]) || c >= arguments.length) ? f = n[s] : (f = arguments[c], c += 1), i[s] = f, t(f) || (a -= 1), s += 1;
        }

        return a <= 0 ? r.apply(this, i) : o(a, u(e, i, r));
      };
    }

    var i = r(function (e, t) {
      return 1 === e ? n(t) : o(e, u(e, [], t));
    });

    function c(e) {
      return function o(u, i, c) {
        switch (arguments.length) {
          case 0:
            return o;

          case 1:
            return t(u) ? o : r(function (t, n) {
              return e(u, t, n);
            });

          case 2:
            return t(u) && t(i) ? o : t(u) ? r(function (t, n) {
              return e(t, i, n);
            }) : t(i) ? r(function (t, n) {
              return e(u, t, n);
            }) : n(function (t) {
              return e(u, i, t);
            });

          default:
            return t(u) && t(i) && t(c) ? o : t(u) && t(i) ? r(function (t, n) {
              return e(t, n, c);
            }) : t(u) && t(c) ? r(function (t, n) {
              return e(t, i, n);
            }) : t(i) && t(c) ? r(function (t, n) {
              return e(u, t, n);
            }) : t(u) ? n(function (t) {
              return e(t, i, c);
            }) : t(i) ? n(function (t) {
              return e(u, t, c);
            }) : t(c) ? n(function (t) {
              return e(u, i, t);
            }) : e(u, i, c);
        }
      };
    }

    var a = Array.isArray || function (e) {
      return null != e && e.length >= 0 && "[object Array]" === Object.prototype.toString.call(e);
    };

    function s(e) {
      return null != e && "function" == typeof e["@@transducer/step"];
    }

    function f(e, t, n) {
      return function () {
        if (0 === arguments.length) return n();
        var r = Array.prototype.slice.call(arguments, 0),
            o = r.pop();

        if (!a(o)) {
          for (var u = 0; u < e.length;) {
            if ("function" == typeof o[e[u]]) return o[e[u]].apply(o, r);
            u += 1;
          }

          if (s(o)) {
            var i = t.apply(null, r);
            return i(o);
          }
        }

        return n.apply(this, arguments);
      };
    }

    var l = function () {
      return this.xf["@@transducer/init"]();
    },
        d = function (e) {
      return this.xf["@@transducer/result"](e);
    };

    function h(e, t) {
      for (var n = 0, r = t.length, o = Array(r); n < r;) o[n] = e(t[n]), n += 1;

      return o;
    }

    function p(e) {
      return "[object String]" === Object.prototype.toString.call(e);
    }

    var y = n(function (e) {
      return !!a(e) || !!e && "object" == typeof e && !p(e) && (1 === e.nodeType ? !!e.length : 0 === e.length || e.length > 0 && e.hasOwnProperty(0) && e.hasOwnProperty(e.length - 1));
    }),
        g = function () {
      function e(e) {
        this.f = e;
      }

      return e.prototype["@@transducer/init"] = function () {
        throw new Error("init not implemented on XWrap");
      }, e.prototype["@@transducer/result"] = function (e) {
        return e;
      }, e.prototype["@@transducer/step"] = function (e, t) {
        return this.f(e, t);
      }, e;
    }();

    var m = r(function (e, t) {
      return o(e.length, function () {
        return e.apply(t, arguments);
      });
    });

    function v(e, t, n) {
      for (var r = n.next(); !r.done;) {
        if ((t = e["@@transducer/step"](t, r.value)) && t["@@transducer/reduced"]) {
          t = t["@@transducer/value"];
          break;
        }

        r = n.next();
      }

      return e["@@transducer/result"](t);
    }

    function b(e, t, n, r) {
      return e["@@transducer/result"](n[r](m(e["@@transducer/step"], e), t));
    }

    var w = "undefined" != typeof Symbol ? Symbol.iterator : "@@iterator";

    function j(e, t, n) {
      if ("function" == typeof e && (e = function (e) {
        return new g(e);
      }(e)), y(n)) return function (e, t, n) {
        for (var r = 0, o = n.length; r < o;) {
          if ((t = e["@@transducer/step"](t, n[r])) && t["@@transducer/reduced"]) {
            t = t["@@transducer/value"];
            break;
          }

          r += 1;
        }

        return e["@@transducer/result"](t);
      }(e, t, n);
      if ("function" == typeof n["fantasy-land/reduce"]) return b(e, t, n, "fantasy-land/reduce");
      if (null != n[w]) return v(e, t, n[w]());
      if ("function" == typeof n.next) return v(e, t, n);
      if ("function" == typeof n.reduce) return b(e, t, n, "reduce");
      throw new TypeError("reduce: list must be array or iterable");
    }

    var A = function () {
      function e(e, t) {
        this.xf = t, this.f = e;
      }

      return e.prototype["@@transducer/init"] = l, e.prototype["@@transducer/result"] = d, e.prototype["@@transducer/step"] = function (e, t) {
        return this.xf["@@transducer/step"](e, this.f(t));
      }, e;
    }(),
        O = r(function (e, t) {
      return new A(e, t);
    });

    function S(e, t) {
      return Object.prototype.hasOwnProperty.call(t, e);
    }

    var N = Object.prototype.toString,
        $ = function () {
      return "[object Arguments]" === N.call(arguments) ? function (e) {
        return "[object Arguments]" === N.call(e);
      } : function (e) {
        return S("callee", e);
      };
    }(),
        E = !{
      toString: null
    }.propertyIsEnumerable("toString"),
        x = ["constructor", "valueOf", "isPrototypeOf", "toString", "propertyIsEnumerable", "hasOwnProperty", "toLocaleString"],
        M = function () {
      return arguments.propertyIsEnumerable("length");
    }(),
        T = function (e, t) {
      for (var n = 0; n < e.length;) {
        if (e[n] === t) return !0;
        n += 1;
      }

      return !1;
    },
        k = "function" != typeof Object.keys || M ? n(function (e) {
      if (Object(e) !== e) return [];
      var t,
          n,
          r = [],
          o = M && $(e);

      for (t in e) !S(t, e) || o && "length" === t || (r[r.length] = t);

      if (E) for (n = x.length - 1; n >= 0;) S(t = x[n], e) && !T(r, t) && (r[r.length] = t), n -= 1;
      return r;
    }) : n(function (e) {
      return Object(e) !== e ? [] : Object.keys(e);
    }),
        P = r(f(["fantasy-land/map", "map"], O, function (e, t) {
      switch (Object.prototype.toString.call(t)) {
        case "[object Function]":
          return i(t.length, function () {
            return e.call(this, t.apply(this, arguments));
          });

        case "[object Object]":
          return j(function (n, r) {
            return n[r] = e(t[r]), n;
          }, {}, k(t));

        default:
          return h(e, t);
      }
    })),
        D = Number.isInteger || function (e) {
      return e << 0 === e;
    },
        C = r(function (e, t) {
      var n = e < 0 ? t.length + e : e;
      return p(t) ? t.charAt(n) : t[n];
    }),
        I = r(function (e, t) {
      return e.map(function (e) {
        for (var n, r = t, o = 0; o < e.length;) {
          if (null == r) return;
          n = e[o], r = D(n) ? C(n, r) : r[n], o += 1;
        }

        return r;
      });
    }),
        F = r(function (e, t) {
      return I([e], t)[0];
    }),
        U = r(function (e, t) {
      return F([e], t);
    }),
        R = c(j),
        q = r(function (e, t) {
      return "function" == typeof t["fantasy-land/ap"] ? t["fantasy-land/ap"](e) : "function" == typeof e.ap ? e.ap(t) : "function" == typeof e ? function (n) {
        return e(n)(t(n));
      } : j(function (e, n) {
        return function (e, t) {
          var n;
          t = t || [];
          var r = (e = e || []).length,
              o = t.length,
              u = [];

          for (n = 0; n < r;) u[u.length] = e[n], n += 1;

          for (n = 0; n < o;) u[u.length] = t[n], n += 1;

          return u;
        }(e, P(n, t));
      }, [], e);
    }),
        _ = n(function (e) {
      for (var t = k(e), n = t.length, r = [], o = 0; o < n;) r[o] = e[t[o]], o += 1;

      return r;
    }),
        z = n(function (e) {
      return null == e;
    });

    function B(e) {
      var t = Object.prototype.toString.call(e);
      return "[object Function]" === t || "[object AsyncFunction]" === t || "[object GeneratorFunction]" === t || "[object AsyncGeneratorFunction]" === t;
    }

    var L = r(function (e, t) {
      var n = i(e, t);
      return i(e, function () {
        return j(q, P(n, arguments[0]), Array.prototype.slice.call(arguments, 1));
      });
    }),
        Y = n(function (e) {
      return L(e.length, e);
    }),
        H = n(function (e) {
      return i(e.length, e);
    });

    function V(e) {
      return function t(n) {
        for (var r, o, u, i = [], c = 0, a = n.length; c < a;) {
          if (y(n[c])) for (u = 0, o = (r = e ? t(n[c]) : n[c]).length; u < o;) i[i.length] = r[u], u += 1;else i[i.length] = n[c];
          c += 1;
        }

        return i;
      };
    }

    var Z = n(function (e) {
      return null === e ? "Null" : void 0 === e ? "Undefined" : Object.prototype.toString.call(e).slice(8, -1);
    }),
        W = Y(n(function (e) {
      return !e;
    }));

    function Q(e, t) {
      return function () {
        return t.call(this, e.apply(this, arguments));
      };
    }

    function G(e, t) {
      return function () {
        var n = arguments.length;
        if (0 === n) return t();
        var r = arguments[n - 1];
        return a(r) || "function" != typeof r[e] ? t.apply(this, arguments) : r[e].apply(r, Array.prototype.slice.call(arguments, 0, n - 1));
      };
    }

    var X = c(G("slice", function (e, t, n) {
      return Array.prototype.slice.call(n, e, t);
    })),
        J = n(G("tail", X(1, 1 / 0)));

    function K() {
      if (0 === arguments.length) throw new Error("pipe requires at least one argument");
      return o(arguments[0].length, R(Q, arguments[0], J(arguments)));
    }

    function ee(e) {
      for (var t, n = []; !(t = e.next()).done;) n.push(t.value);

      return n;
    }

    function te(e, t, n) {
      for (var r = 0, o = n.length; r < o;) {
        if (e(t, n[r])) return !0;
        r += 1;
      }

      return !1;
    }

    var ne = "function" == typeof Object.is ? Object.is : function (e, t) {
      return e === t ? 0 !== e || 1 / e == 1 / t : e != e && t != t;
    };

    function re(e, t, n, r) {
      var o = ee(e);

      function u(e, t) {
        return oe(e, t, n.slice(), r.slice());
      }

      return !te(function (e, t) {
        return !te(u, t, e);
      }, ee(t), o);
    }

    function oe(e, t, n, r) {
      if (ne(e, t)) return !0;
      var o,
          u,
          i = Z(e);
      if (i !== Z(t)) return !1;
      if (null == e || null == t) return !1;
      if ("function" == typeof e["fantasy-land/equals"] || "function" == typeof t["fantasy-land/equals"]) return "function" == typeof e["fantasy-land/equals"] && e["fantasy-land/equals"](t) && "function" == typeof t["fantasy-land/equals"] && t["fantasy-land/equals"](e);
      if ("function" == typeof e.equals || "function" == typeof t.equals) return "function" == typeof e.equals && e.equals(t) && "function" == typeof t.equals && t.equals(e);

      switch (i) {
        case "Arguments":
        case "Array":
        case "Object":
          if ("function" == typeof e.constructor && "Promise" === (o = e.constructor, null == (u = String(o).match(/^function (\w*)/)) ? "" : u[1])) return e === t;
          break;

        case "Boolean":
        case "Number":
        case "String":
          if (typeof e != typeof t || !ne(e.valueOf(), t.valueOf())) return !1;
          break;

        case "Date":
          if (!ne(e.valueOf(), t.valueOf())) return !1;
          break;

        case "Error":
          return e.name === t.name && e.message === t.message;

        case "RegExp":
          if (e.source !== t.source || e.global !== t.global || e.ignoreCase !== t.ignoreCase || e.multiline !== t.multiline || e.sticky !== t.sticky || e.unicode !== t.unicode) return !1;
      }

      for (var c = n.length - 1; c >= 0;) {
        if (n[c] === e) return r[c] === t;
        c -= 1;
      }

      switch (i) {
        case "Map":
          return e.size === t.size && re(e.entries(), t.entries(), n.concat([e]), r.concat([t]));

        case "Set":
          return e.size === t.size && re(e.values(), t.values(), n.concat([e]), r.concat([t]));

        case "Arguments":
        case "Array":
        case "Object":
        case "Boolean":
        case "Number":
        case "String":
        case "Date":
        case "Error":
        case "RegExp":
        case "Int8Array":
        case "Uint8Array":
        case "Uint8ClampedArray":
        case "Int16Array":
        case "Uint16Array":
        case "Int32Array":
        case "Uint32Array":
        case "Float32Array":
        case "Float64Array":
        case "ArrayBuffer":
          break;

        default:
          return !1;
      }

      var a = k(e);
      if (a.length !== k(t).length) return !1;
      var s = n.concat([e]),
          f = r.concat([t]);

      for (c = a.length - 1; c >= 0;) {
        var l = a[c];
        if (!S(l, t) || !oe(t[l], e[l], s, f)) return !1;
        c -= 1;
      }

      return !0;
    }

    var ue = r(function (e, t) {
      return oe(e, t, [], []);
    });

    function ie(e, t) {
      return function (e, t, n) {
        var r, o;
        if ("function" == typeof e.indexOf) switch (typeof t) {
          case "number":
            if (0 === t) {
              for (r = 1 / t; n < e.length;) {
                if (0 === (o = e[n]) && 1 / o === r) return n;
                n += 1;
              }

              return -1;
            }

            if (t != t) {
              for (; n < e.length;) {
                if ("number" == typeof (o = e[n]) && o != o) return n;
                n += 1;
              }

              return -1;
            }

            return e.indexOf(t, n);

          case "string":
          case "boolean":
          case "function":
          case "undefined":
            return e.indexOf(t, n);

          case "object":
            if (null === t) return e.indexOf(t, n);
        }

        for (; n < e.length;) {
          if (ue(e[n], t)) return n;
          n += 1;
        }

        return -1;
      }(t, e, 0) >= 0;
    }

    function ce(e) {
      return '"' + e.replace(/\\/g, "\\\\").replace(/[\b]/g, "\\b").replace(/\f/g, "\\f").replace(/\n/g, "\\n").replace(/\r/g, "\\r").replace(/\t/g, "\\t").replace(/\v/g, "\\v").replace(/\0/g, "\\0").replace(/"/g, '\\"') + '"';
    }

    var ae = function (e) {
      return (e < 10 ? "0" : "") + e;
    },
        se = "function" == typeof Date.prototype.toISOString ? function (e) {
      return e.toISOString();
    } : function (e) {
      return e.getUTCFullYear() + "-" + ae(e.getUTCMonth() + 1) + "-" + ae(e.getUTCDate()) + "T" + ae(e.getUTCHours()) + ":" + ae(e.getUTCMinutes()) + ":" + ae(e.getUTCSeconds()) + "." + (e.getUTCMilliseconds() / 1e3).toFixed(3).slice(2, 5) + "Z";
    };

    function fe(e) {
      return "[object Object]" === Object.prototype.toString.call(e);
    }

    var le = function () {
      function e(e, t) {
        this.xf = t, this.f = e;
      }

      return e.prototype["@@transducer/init"] = l, e.prototype["@@transducer/result"] = d, e.prototype["@@transducer/step"] = function (e, t) {
        return this.f(t) ? this.xf["@@transducer/step"](e, t) : e;
      }, e;
    }(),
        de = r(f(["filter"], r(function (e, t) {
      return new le(e, t);
    }), function (e, t) {
      return fe(t) ? j(function (n, r) {
        return e(t[r]) && (n[r] = t[r]), n;
      }, {}, k(t)) : function (e, t) {
        for (var n = 0, r = t.length, o = []; n < r;) e(t[n]) && (o[o.length] = t[n]), n += 1;

        return o;
      }(e, t);
    })),
        he = r(function (e, t) {
      return de((n = e, function () {
        return !n.apply(this, arguments);
      }), t);
      var n;
    });

    function pe(e, t) {
      var n = function (n) {
        var r = t.concat([e]);
        return ie(n, r) ? "<Circular>" : pe(n, r);
      },
          r = function (e, t) {
        return h(function (t) {
          return ce(t) + ": " + n(e[t]);
        }, t.slice().sort());
      };

      switch (Object.prototype.toString.call(e)) {
        case "[object Arguments]":
          return "(function() { return arguments; }(" + h(n, e).join(", ") + "))";

        case "[object Array]":
          return "[" + h(n, e).concat(r(e, he(function (e) {
            return /^\d+$/.test(e);
          }, k(e)))).join(", ") + "]";

        case "[object Boolean]":
          return "object" == typeof e ? "new Boolean(" + n(e.valueOf()) + ")" : e.toString();

        case "[object Date]":
          return "new Date(" + (isNaN(e.valueOf()) ? n(NaN) : ce(se(e))) + ")";

        case "[object Null]":
          return "null";

        case "[object Number]":
          return "object" == typeof e ? "new Number(" + n(e.valueOf()) + ")" : 1 / e == -1 / 0 ? "-0" : e.toString(10);

        case "[object String]":
          return "object" == typeof e ? "new String(" + n(e.valueOf()) + ")" : ce(e);

        case "[object Undefined]":
          return "undefined";

        default:
          if ("function" == typeof e.toString) {
            var o = e.toString();
            if ("[object Object]" !== o) return o;
          }

          return "{" + r(e, k(e)).join(", ") + "}";
      }
    }

    var ye = n(function (e) {
      return pe(e, []);
    }),
        ge = r(function (e, t) {
      if (a(e)) {
        if (a(t)) return e.concat(t);
        throw new TypeError(ye(t) + " is not an array");
      }

      if (p(e)) {
        if (p(t)) return e + t;
        throw new TypeError(ye(t) + " is not a string");
      }

      if (null != e && B(e["fantasy-land/concat"])) return e["fantasy-land/concat"](t);
      if (null != e && B(e.concat)) return e.concat(t);
      throw new TypeError(ye(e) + ' does not have a method named "concat" or "fantasy-land/concat"');
    }),
        me = n(function (e) {
      return null != e && "function" == typeof e["fantasy-land/empty"] ? e["fantasy-land/empty"]() : null != e && null != e.constructor && "function" == typeof e.constructor["fantasy-land/empty"] ? e.constructor["fantasy-land/empty"]() : null != e && "function" == typeof e.empty ? e.empty() : null != e && null != e.constructor && "function" == typeof e.constructor.empty ? e.constructor.empty() : a(e) ? [] : p(e) ? "" : fe(e) ? {} : $(e) ? function () {
        return arguments;
      }() : void 0;
    }),
        ve = function () {
      function e(e, t) {
        this.xf = t, this.f = e, this.found = !1;
      }

      return e.prototype["@@transducer/init"] = l, e.prototype["@@transducer/result"] = function (e) {
        return this.found || (e = this.xf["@@transducer/step"](e, void 0)), this.xf["@@transducer/result"](e);
      }, e.prototype["@@transducer/step"] = function (e, t) {
        var n;
        return this.f(t) && (this.found = !0, e = (n = this.xf["@@transducer/step"](e, t)) && n["@@transducer/reduced"] ? n : {
          "@@transducer/value": n,
          "@@transducer/reduced": !0
        }), e;
      }, e;
    }(),
        be = r(f(["find"], r(function (e, t) {
      return new ve(e, t);
    }), function (e, t) {
      for (var n = 0, r = t.length; n < r;) {
        if (e(t[n])) return t[n];
        n += 1;
      }
    })),
        we = n(V(!0)),
        je = n(function (e) {
      for (var t = {}, n = 0; n < e.length;) t[e[n][0]] = e[n][1], n += 1;

      return t;
    }),
        Ae = r(function (e, t) {
      if (0 === e.length || z(t)) return !1;

      for (var n = t, r = 0; r < e.length;) {
        if (z(n) || !S(e[r], n)) return !1;
        n = n[e[r]], r += 1;
      }

      return !0;
    });

    var Oe = "function" == typeof Object.assign ? Object.assign : function (e) {
      if (null == e) throw new TypeError("Cannot convert undefined or null to object");

      for (var t = Object(e), n = 1, r = arguments.length; n < r;) {
        var o = arguments[n];
        if (null != o) for (var u in o) S(u, o) && (t[u] = o[u]);
        n += 1;
      }

      return t;
    },
        Se = r(function (e, t) {
      return i(e + 1, function () {
        var n = arguments[e];
        if (null != n && B(n[t])) return n[t].apply(n, Array.prototype.slice.call(arguments, 0, e));
        throw new TypeError(ye(n) + ' does not have a method named "' + t + '"');
      });
    }),
        Ne = r(function (e, t) {
      return null != t && t.constructor === e || t instanceof e;
    }),
        $e = n(function (e) {
      return null != e && ue(e, me(e));
    }),
        Ee = n(function (e) {
      return Oe.apply(null, [{}].concat(e));
    }),
        xe = r(function (e, t) {
      for (var n = {}, r = {}, o = 0, u = e.length; o < u;) r[e[o]] = 1, o += 1;

      for (var i in t) r.hasOwnProperty(i) || (n[i] = t[i]);

      return n;
    }),
        Me = c(function (e, t, n) {
      return ue(t, n[e]);
    }),
        Te = c(function (e, t, n) {
      return n.replace(e, t);
    }),
        ke = Se(1, "split"),
        Pe = "\t\n\v\f\r   ᠎             　\u2028\u2029\ufeff",
        De = n("function" == typeof String.prototype.trim && !Pe.trim() && "​".trim() ? function (e) {
      return e.trim();
    } : function (e) {
      var t = new RegExp("^[" + Pe + "][" + Pe + "]*"),
          n = new RegExp("[" + Pe + "][" + Pe + "]*$");
      return e.replace(t, "").replace(n, "");
    });

    const Ce = e => {
      if (z(e) || $e(e)) return e;

      switch (Z(e)) {
        case "String":
          return De(e);

        case "Array":
          return de(W($e))(e);

        default:
          return e;
      }
    },
          Ie = (e, t) => $e(t) || z(t) ? [] : K(ke(e), Ce)(t),
          Fe = {
      set: (e, t) => {
        "undefined" != typeof window && window.sessionStorage.setItem(e, t);
      },
      get: e => "undefined" != typeof window ? window.sessionStorage.getItem(e) : null,
      remove: e => {
        "undefined" != typeof window && window.sessionStorage.removeItem(e);
      },
      clear: () => {
        "undefined" != typeof window && window.sessionStorage.clear();
      }
    },
          Ue = {
      set: (e, t) => {
        "undefined" != typeof window && window.localStorage.setItem(e, t);
      },
      get: e => "undefined" != typeof window ? window.localStorage.getItem(e) : null,
      remove: e => {
        "undefined" != typeof window && window.localStorage.removeItem(e);
      },
      clear: () => {
        "undefined" != typeof window && window.localStorage.clear();
      }
    },
          Re = {
      set: (e, t, n) => {
        const r = new Date();
        r.setTime(r.getTime() + n);
        const o = `expires=${r.toUTCString()}`;
        document.cookie = `${e}=${t};${o};path=/`;
      },
      get: e => {
        const t = `${e}=`,
              n = document.cookie.split(";");

        for (let e = 0; e < n.length; e += 1) {
          let r = n[e];

          for (; " " === r.charAt(0);) r = r.substring(1);

          if (-1 !== r.indexOf(t)) return r.substring(t.length, r.length);
        }
      }
    };

    function qe(e, t, n, r) {
      e.addEventListener(t, function r(o) {
        e.removeEventListener(t, r), n(o);
      }, r);
    }

    const _e = ["id", "type", "async", "defer", "crossOrigin", "integrity", "noModule"];

    const ze = e => {
      let t = e;
      return Ne(String, e) && String(e).length >= 13 && !isNaN(e) && (t = Number(e)), new Date(t) && "Invalid Date" !== String(new Date(t));
    },
          Be = (e, t, n) => {
      const r = {
        reduce: H((e, n, o) => {
          const u = e(n, o);
          return (e => Ae([t], e))(o) && o[t] ? o[t].reduce(r.reduce(e), u) : u;
        }),
        find: H((e, t, n) => K(P(r.reduce(e, t)), we)(n))
      },
            o = (n, r) => e.value && r[e.key] && r[e.key] === e.value || !e.value && r[e.key] ? n.concat([xe([t], r)]) : n;

      switch (Z(n)) {
        case "Object":
          return r.reduce(o, [])(n);

        case "Array":
          return r.find(o, [])(n);

        default:
          return n;
      }
    },
          Le = (e, t) => {
      let n = [],
          r = [],
          o = {};
      const u = be(Me("origion_url", `/${e[0]}`))(t);

      if (u) {
        if (n = [u.name], e.length > 1 && u.children && u.children.length) {
          const t = e.join("/");
          o = be(Me("origion_url", `/${t}`))(u.children);
        } else o = u.children && u.children.length ? u.children[0] : u;

        r = (null == o ? void 0 : o.name) ? [o.name] : [];
      }

      return {
        defaultOpenMenus: n,
        defaultSelectedMenus: r,
        defaultMenu: o
      };
    },
          Ye = e => {
      var t, n;
      let r = [],
          o = [],
          u = {};
      return e[0] && e[0].children && e[0].children.length ? (r = [e[0].name], o = [e[0].children[0].name], u = e[0].children[0]) : e[0] && (r = [null === (t = e[0]) || void 0 === t ? void 0 : t.name], o = [null === (n = e[0]) || void 0 === n ? void 0 : n.name], u = e[0]), {
        defaultOpenMenus: r,
        defaultSelectedMenus: o,
        defaultMenu: u
      };
    },
          He = () => {
      let e = "prod";
      const t = "prod" == String(process.env.REACT_APP_ENV);
      return e = "undefined" == typeof window ? (t ? "prod" : process.env.REACT_APP_ENV) || "prod" : window.localStorage.getItem("env") || (t ? "prod" : process.env.REACT_APP_ENV) || "prod", e;
    },
          Ve = e => {
      if (!e) return {};
      return K(Te("?", ""), ke("&"), P(e => ke("=", decodeURI(e))), je)(e);
    };

    var Ze = Object.freeze({
      __proto__: null,
      parse: Ve,
      stringify: e => {
        if ($e(e)) return "";
        const t = Object.keys(e);
        let n = "";
        t.map(t => {
          n += `&${t}=${e[t]}`;
        });
        return new URLSearchParams(n).toString() || "";
      }
    });
    var We = 1e6,
        Qe = 1e6,
        Ge = "[big.js] ",
        Xe = Ge + "Invalid ",
        Je = Xe + "decimal places",
        Ke = Xe + "rounding mode",
        et = Ge + "Division by zero",
        tt = {},
        nt = void 0,
        rt = /^-?(\d+(\.\d*)?|\.\d+)(e[+-]?\d+)?$/i;

    function ot(e, t, n, r) {
      var o = e.c,
          u = e.e + t + 1;

      if (u < o.length) {
        if (1 === n) r = o[u] >= 5;else if (2 === n) r = o[u] > 5 || 5 == o[u] && (r || u < 0 || o[u + 1] !== nt || 1 & o[u - 1]);else if (3 === n) r = r || !!o[0];else if (r = !1, 0 !== n) throw Error(Ke);
        if (u < 1) o.length = 1, r ? (e.e = -t, o[0] = 1) : o[0] = e.e = 0;else {
          if (o.length = u--, r) for (; ++o[u] > 9;) o[u] = 0, u-- || (++e.e, o.unshift(1));

          for (u = o.length; !o[--u];) o.pop();
        }
      } else if (n < 0 || n > 3 || n !== ~~n) throw Error(Ke);

      return e;
    }

    function ut(e, t, n, r) {
      var o,
          u,
          i = e.constructor,
          c = !e.c[0];

      if (n !== nt) {
        if (n !== ~~n || n < (3 == t) || n > We) throw Error(3 == t ? Xe + "precision" : Je);

        for (n = r - (e = new i(e)).e, e.c.length > ++r && ot(e, n, i.RM), 2 == t && (r = e.e + n + 1); e.c.length < r;) e.c.push(0);
      }

      if (o = e.e, n = (u = e.c.join("")).length, 2 != t && (1 == t || 3 == t && r <= o || o <= i.NE || o >= i.PE)) u = u.charAt(0) + (n > 1 ? "." + u.slice(1) : "") + (o < 0 ? "e" : "e+") + o;else if (o < 0) {
        for (; ++o;) u = "0" + u;

        u = "0." + u;
      } else if (o > 0) {
        if (++o > n) for (o -= n; o--;) u += "0";else o < n && (u = u.slice(0, o) + "." + u.slice(o));
      } else n > 1 && (u = u.charAt(0) + "." + u.slice(1));
      return e.s < 0 && (!c || 4 == t) ? "-" + u : u;
    }

    tt.abs = function () {
      var e = new this.constructor(this);
      return e.s = 1, e;
    }, tt.cmp = function (e) {
      var t,
          n = this,
          r = n.c,
          o = (e = new n.constructor(e)).c,
          u = n.s,
          i = e.s,
          c = n.e,
          a = e.e;
      if (!r[0] || !o[0]) return r[0] ? u : o[0] ? -i : 0;
      if (u != i) return u;
      if (t = u < 0, c != a) return c > a ^ t ? 1 : -1;

      for (i = (c = r.length) < (a = o.length) ? c : a, u = -1; ++u < i;) if (r[u] != o[u]) return r[u] > o[u] ^ t ? 1 : -1;

      return c == a ? 0 : c > a ^ t ? 1 : -1;
    }, tt.div = function (e) {
      var t = this,
          n = t.constructor,
          r = t.c,
          o = (e = new n(e)).c,
          u = t.s == e.s ? 1 : -1,
          i = n.DP;
      if (i !== ~~i || i < 0 || i > We) throw Error(Je);
      if (!o[0]) throw Error(et);
      if (!r[0]) return new n(0 * u);
      var c,
          a,
          s,
          f,
          l,
          d = o.slice(),
          h = c = o.length,
          p = r.length,
          y = r.slice(0, c),
          g = y.length,
          m = e,
          v = m.c = [],
          b = 0,
          w = i + (m.e = t.e - e.e) + 1;

      for (m.s = u, u = w < 0 ? 0 : w, d.unshift(0); g++ < c;) y.push(0);

      do {
        for (s = 0; s < 10; s++) {
          if (c != (g = y.length)) f = c > g ? 1 : -1;else for (l = -1, f = 0; ++l < c;) if (o[l] != y[l]) {
            f = o[l] > y[l] ? 1 : -1;
            break;
          }
          if (!(f < 0)) break;

          for (a = g == c ? o : d; g;) {
            if (y[--g] < a[g]) {
              for (l = g; l && !y[--l];) y[l] = 9;

              --y[l], y[g] += 10;
            }

            y[g] -= a[g];
          }

          for (; !y[0];) y.shift();
        }

        v[b++] = f ? s : ++s, y[0] && f ? y[g] = r[h] || 0 : y = [r[h]];
      } while ((h++ < p || y[0] !== nt) && u--);

      return v[0] || 1 == b || (v.shift(), m.e--), b > w && ot(m, i, n.RM, y[0] !== nt), m;
    }, tt.eq = function (e) {
      return !this.cmp(e);
    }, tt.gt = function (e) {
      return this.cmp(e) > 0;
    }, tt.gte = function (e) {
      return this.cmp(e) > -1;
    }, tt.lt = function (e) {
      return this.cmp(e) < 0;
    }, tt.lte = function (e) {
      return this.cmp(e) < 1;
    }, tt.minus = tt.sub = function (e) {
      var t,
          n,
          r,
          o,
          u = this,
          i = u.constructor,
          c = u.s,
          a = (e = new i(e)).s;
      if (c != a) return e.s = -a, u.plus(e);
      var s = u.c.slice(),
          f = u.e,
          l = e.c,
          d = e.e;
      if (!s[0] || !l[0]) return l[0] ? (e.s = -a, e) : new i(s[0] ? u : 0);

      if (c = f - d) {
        for ((o = c < 0) ? (c = -c, r = s) : (d = f, r = l), r.reverse(), a = c; a--;) r.push(0);

        r.reverse();
      } else for (n = ((o = s.length < l.length) ? s : l).length, c = a = 0; a < n; a++) if (s[a] != l[a]) {
        o = s[a] < l[a];
        break;
      }

      if (o && (r = s, s = l, l = r, e.s = -e.s), (a = (n = l.length) - (t = s.length)) > 0) for (; a--;) s[t++] = 0;

      for (a = t; n > c;) {
        if (s[--n] < l[n]) {
          for (t = n; t && !s[--t];) s[t] = 9;

          --s[t], s[n] += 10;
        }

        s[n] -= l[n];
      }

      for (; 0 === s[--a];) s.pop();

      for (; 0 === s[0];) s.shift(), --d;

      return s[0] || (e.s = 1, s = [d = 0]), e.c = s, e.e = d, e;
    }, tt.mod = function (e) {
      var t,
          n = this,
          r = n.constructor,
          o = n.s,
          u = (e = new r(e)).s;
      if (!e.c[0]) throw Error(et);
      return n.s = e.s = 1, t = 1 == e.cmp(n), n.s = o, e.s = u, t ? new r(n) : (o = r.DP, u = r.RM, r.DP = r.RM = 0, n = n.div(e), r.DP = o, r.RM = u, this.minus(n.times(e)));
    }, tt.plus = tt.add = function (e) {
      var t,
          n = this,
          r = n.constructor,
          o = n.s,
          u = (e = new r(e)).s;
      if (o != u) return e.s = -u, n.minus(e);
      var i = n.e,
          c = n.c,
          a = e.e,
          s = e.c;
      if (!c[0] || !s[0]) return s[0] ? e : new r(c[0] ? n : 0 * o);

      if (c = c.slice(), o = i - a) {
        for (o > 0 ? (a = i, t = s) : (o = -o, t = c), t.reverse(); o--;) t.push(0);

        t.reverse();
      }

      for (c.length - s.length < 0 && (t = s, s = c, c = t), o = s.length, u = 0; o; c[o] %= 10) u = (c[--o] = c[o] + s[o] + u) / 10 | 0;

      for (u && (c.unshift(u), ++a), o = c.length; 0 === c[--o];) c.pop();

      return e.c = c, e.e = a, e;
    }, tt.pow = function (e) {
      var t = this,
          n = new t.constructor(1),
          r = n,
          o = e < 0;
      if (e !== ~~e || e < -1e6 || e > Qe) throw Error(Xe + "exponent");

      for (o && (e = -e); 1 & e && (r = r.times(t)), e >>= 1;) t = t.times(t);

      return o ? n.div(r) : r;
    }, tt.round = function (e, t) {
      var n = this.constructor;
      if (e === nt) e = 0;else if (e !== ~~e || e < -We || e > We) throw Error(Je);
      return ot(new n(this), e, t === nt ? n.RM : t);
    }, tt.sqrt = function () {
      var e,
          t,
          n,
          r = this,
          o = r.constructor,
          u = r.s,
          i = r.e,
          c = new o(.5);
      if (!r.c[0]) return new o(r);
      if (u < 0) throw Error(Ge + "No square root");
      0 === (u = Math.sqrt(r + "")) || u === 1 / 0 ? ((t = r.c.join("")).length + i & 1 || (t += "0"), i = ((i + 1) / 2 | 0) - (i < 0 || 1 & i), e = new o(((u = Math.sqrt(t)) == 1 / 0 ? "1e" : (u = u.toExponential()).slice(0, u.indexOf("e") + 1)) + i)) : e = new o(u), i = e.e + (o.DP += 4);

      do {
        n = e, e = c.times(n.plus(r.div(n)));
      } while (n.c.slice(0, i).join("") !== e.c.slice(0, i).join(""));

      return ot(e, o.DP -= 4, o.RM);
    }, tt.times = tt.mul = function (e) {
      var t,
          n = this,
          r = n.constructor,
          o = n.c,
          u = (e = new r(e)).c,
          i = o.length,
          c = u.length,
          a = n.e,
          s = e.e;
      if (e.s = n.s == e.s ? 1 : -1, !o[0] || !u[0]) return new r(0 * e.s);

      for (e.e = a + s, i < c && (t = o, o = u, u = t, s = i, i = c, c = s), t = new Array(s = i + c); s--;) t[s] = 0;

      for (a = c; a--;) {
        for (c = 0, s = i + a; s > a;) c = t[s] + u[a] * o[s - a - 1] + c, t[s--] = c % 10, c = c / 10 | 0;

        t[s] = (t[s] + c) % 10;
      }

      for (c ? ++e.e : t.shift(), a = t.length; !t[--a];) t.pop();

      return e.c = t, e;
    }, tt.toExponential = function (e) {
      return ut(this, 1, e, e);
    }, tt.toFixed = function (e) {
      return ut(this, 2, e, this.e + e);
    }, tt.toPrecision = function (e) {
      return ut(this, 3, e, e - 1);
    }, tt.toString = function () {
      return ut(this);
    }, tt.valueOf = tt.toJSON = function () {
      return ut(this, 4);
    };

    var it = function e() {
      function t(n) {
        var r = this;
        if (!(r instanceof t)) return n === nt ? e() : new t(n);
        n instanceof t ? (r.s = n.s, r.e = n.e, r.c = n.c.slice()) : function (e, t) {
          var n, r, o;
          if (0 === t && 1 / t < 0) t = "-0";else if (!rt.test(t += "")) throw Error(Xe + "number");
          e.s = "-" == t.charAt(0) ? (t = t.slice(1), -1) : 1, (n = t.indexOf(".")) > -1 && (t = t.replace(".", ""));
          (r = t.search(/e/i)) > 0 ? (n < 0 && (n = r), n += +t.slice(r + 1), t = t.substring(0, r)) : n < 0 && (n = t.length);

          for (o = t.length, r = 0; r < o && "0" == t.charAt(r);) ++r;

          if (r == o) e.c = [e.e = 0];else {
            for (; o > 0 && "0" == t.charAt(--o););

            for (e.e = n - r - 1, e.c = [], n = 0; r <= o;) e.c[n++] = +t.charAt(r++);
          }
        }(r, n), r.constructor = t;
      }

      return t.prototype = tt, t.DP = 20, t.RM = 1, t.NE = -7, t.PE = 21, t.version = "5.2.2", t;
    }();

    const ct = (e, t) => {
      const n = (e = e.toString()).indexOf(".");
      return e = -1 !== n ? e.substring(0, t + n + 1) : e.substring(0), Number(parseFloat(e).toFixed(t));
    },
          at = e => (t, n) => {
      if ($e(t) || z(t)) return t;
      if (isNaN(Number(t))) return NaN;
      const r = Number(new it(Number(t)).mul(e));
      if (z(null == n ? void 0 : n.decimalNumber) && z(null == n ? void 0 : n.fn)) return r;
      if (!z(null == n ? void 0 : n.decimalNumber) && z(null == n ? void 0 : n.fn)) return Number(r.toFixed(null == n ? void 0 : n.decimalNumber));

      if (!z(null == n ? void 0 : n.decimalNumber) && !z(null == n ? void 0 : n.fn)) {
        if ("toFixed" === (null == n ? void 0 : n.fn)) return Number(r.toFixed(null == n ? void 0 : n.decimalNumber));
        if ("floor" === (null == n ? void 0 : n.fn)) return ct(r, null == n ? void 0 : n.decimalNumber);
      }
    },
          st = e => (t, n) => {
      const r = (null == n ? void 0 : n.decimalNumber) || 2,
            o = (null == n ? void 0 : n.fn) || "toFixed";
      if ($e(t) || z(t)) return t;
      if (isNaN(Number(t))) return NaN;
      const u = new it(Number(t)).div(e);
      return "toFixed" === o ? Number(u.toFixed(r)) : "floor" === o ? ct(Number(u), r) : t;
    },
          ft = e => {
      const t = Object.prototype.toString.call(e),
            n = /^\[object (.*)\]$/.exec(t);
      return null !== n ? n[1].toLowerCase() : null;
    },
          lt = e => "string" == typeof e ? De(e) : ("array" !== ft(e) && "object" !== ft(e) || (Array.isArray(e) && e.forEach(e => {
      lt(e);
    }), null === typeof e) || Object.keys(e).map(t => {
      const n = e[t];
      "string" == typeof n && (e[t] = De(n)), "object" !== ft(n) && "array" !== ft(n) || lt(n);
    }), e);

    var dt,
        ht = new Uint8Array(16);

    function pt() {
      if (!dt && !(dt = "undefined" != typeof crypto && crypto.getRandomValues && crypto.getRandomValues.bind(crypto) || "undefined" != typeof msCrypto && "function" == typeof msCrypto.getRandomValues && msCrypto.getRandomValues.bind(msCrypto))) throw new Error("crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported");
      return dt(ht);
    }

    var yt = /^(?:[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}|00000000-0000-0000-0000-000000000000)$/i;

    function gt(e) {
      return "string" == typeof e && yt.test(e);
    }

    for (var mt = [], vt = 0; vt < 256; ++vt) mt.push((vt + 256).toString(16).substr(1));

    function bt(e, t, n) {
      var r = (e = e || {}).random || (e.rng || pt)();

      if (r[6] = 15 & r[6] | 64, r[8] = 63 & r[8] | 128, t) {
        n = n || 0;

        for (var o = 0; o < 16; ++o) t[n + o] = r[o];

        return t;
      }

      return function (e) {
        var t = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : 0,
            n = (mt[e[t + 0]] + mt[e[t + 1]] + mt[e[t + 2]] + mt[e[t + 3]] + "-" + mt[e[t + 4]] + mt[e[t + 5]] + "-" + mt[e[t + 6]] + mt[e[t + 7]] + "-" + mt[e[t + 8]] + mt[e[t + 9]] + "-" + mt[e[t + 10]] + mt[e[t + 11]] + mt[e[t + 12]] + mt[e[t + 13]] + mt[e[t + 14]] + mt[e[t + 15]]).toLowerCase();
        if (!gt(n)) throw TypeError("Stringified UUID is invalid");
        return n;
      }(r);
    }

    const wt = "input is invalid type",
          jt = "0123456789abcdef".split(""),
          At = [128, 32768, 8388608, -2147483648];
    let Ot,
        St = [];
    const Nt = new ArrayBuffer(68);
    Ot = new Uint8Array(Nt), St = new Uint32Array(Nt);

    function $t() {
      St[0] = St[16] = St[1] = St[2] = St[3] = St[4] = St[5] = St[6] = St[7] = St[8] = St[9] = St[10] = St[11] = St[12] = St[13] = St[14] = St[15] = 0, this.blocks = St, this.buffer8 = Ot, this.h0 = this.h1 = this.h2 = this.h3 = this.start = this.bytes = this.hBytes = 0, this.finalized = this.hashed = !1, this.first = !0;
    }

    $t.prototype.update = function (e) {
      if (this.finalized) return;
      let t;
      const n = typeof e;

      if ("string" !== n) {
        if ("object" !== n) throw wt;
        if (null === e) throw wt;
        if (e.constructor === ArrayBuffer) e = new Uint8Array(e);else if (!Array.isArray(e) && !ArrayBuffer.isView(e)) throw wt;
        t = !0;
      }

      let r,
          o,
          u = 0,
          i = e.length,
          c = this.blocks,
          a = this.buffer8;

      for (; u < i;) {
        if (this.hashed && (this.hashed = !1, c[0] = c[16], c[16] = c[1] = c[2] = c[3] = c[4] = c[5] = c[6] = c[7] = c[8] = c[9] = c[10] = c[11] = c[12] = c[13] = c[14] = c[15] = 0), t) for (o = this.start; u < i && o < 64; ++u) a[o++] = e[u];else for (o = this.start; u < i && o < 64; ++u) r = e.charCodeAt(u), r < 128 ? a[o++] = r : r < 2048 ? (a[o++] = 192 | r >> 6, a[o++] = 128 | 63 & r) : r < 55296 || r >= 57344 ? (a[o++] = 224 | r >> 12, a[o++] = 128 | r >> 6 & 63, a[o++] = 128 | 63 & r) : (r = 65536 + ((1023 & r) << 10 | 1023 & e.charCodeAt(++u)), a[o++] = 240 | r >> 18, a[o++] = 128 | r >> 12 & 63, a[o++] = 128 | r >> 6 & 63, a[o++] = 128 | 63 & r);
        this.lastByteIndex = o, this.bytes += o - this.start, o >= 64 ? (this.start = o - 64, this.hash(), this.hashed = !0) : this.start = o;
      }

      return this.bytes > 4294967295 && (this.hBytes += this.bytes / 4294967296 << 0, this.bytes = this.bytes % 4294967296), this;
    }, $t.prototype.finalize = function () {
      if (this.finalized) return;
      this.finalized = !0;
      const e = this.blocks,
            t = this.lastByteIndex;
      e[t >> 2] |= At[3 & t], t >= 56 && (this.hashed || this.hash(), e[0] = e[16], e[16] = e[1] = e[2] = e[3] = e[4] = e[5] = e[6] = e[7] = e[8] = e[9] = e[10] = e[11] = e[12] = e[13] = e[14] = e[15] = 0), e[14] = this.bytes << 3, e[15] = this.hBytes << 3 | this.bytes >>> 29, this.hash();
    }, $t.prototype.hash = function () {
      let e,
          t,
          n,
          r,
          o,
          u,
          i = this.blocks;
      this.first ? (e = i[0] - 680876937, e = (e << 7 | e >>> 25) - 271733879 << 0, r = (-1732584194 ^ 2004318071 & e) + i[1] - 117830708, r = (r << 12 | r >>> 20) + e << 0, n = (-271733879 ^ r & (-271733879 ^ e)) + i[2] - 1126478375, n = (n << 17 | n >>> 15) + r << 0, t = (e ^ n & (r ^ e)) + i[3] - 1316259209, t = (t << 22 | t >>> 10) + n << 0) : (e = this.h0, t = this.h1, n = this.h2, r = this.h3, e += (r ^ t & (n ^ r)) + i[0] - 680876936, e = (e << 7 | e >>> 25) + t << 0, r += (n ^ e & (t ^ n)) + i[1] - 389564586, r = (r << 12 | r >>> 20) + e << 0, n += (t ^ r & (e ^ t)) + i[2] + 606105819, n = (n << 17 | n >>> 15) + r << 0, t += (e ^ n & (r ^ e)) + i[3] - 1044525330, t = (t << 22 | t >>> 10) + n << 0), e += (r ^ t & (n ^ r)) + i[4] - 176418897, e = (e << 7 | e >>> 25) + t << 0, r += (n ^ e & (t ^ n)) + i[5] + 1200080426, r = (r << 12 | r >>> 20) + e << 0, n += (t ^ r & (e ^ t)) + i[6] - 1473231341, n = (n << 17 | n >>> 15) + r << 0, t += (e ^ n & (r ^ e)) + i[7] - 45705983, t = (t << 22 | t >>> 10) + n << 0, e += (r ^ t & (n ^ r)) + i[8] + 1770035416, e = (e << 7 | e >>> 25) + t << 0, r += (n ^ e & (t ^ n)) + i[9] - 1958414417, r = (r << 12 | r >>> 20) + e << 0, n += (t ^ r & (e ^ t)) + i[10] - 42063, n = (n << 17 | n >>> 15) + r << 0, t += (e ^ n & (r ^ e)) + i[11] - 1990404162, t = (t << 22 | t >>> 10) + n << 0, e += (r ^ t & (n ^ r)) + i[12] + 1804603682, e = (e << 7 | e >>> 25) + t << 0, r += (n ^ e & (t ^ n)) + i[13] - 40341101, r = (r << 12 | r >>> 20) + e << 0, n += (t ^ r & (e ^ t)) + i[14] - 1502002290, n = (n << 17 | n >>> 15) + r << 0, t += (e ^ n & (r ^ e)) + i[15] + 1236535329, t = (t << 22 | t >>> 10) + n << 0, e += (n ^ r & (t ^ n)) + i[1] - 165796510, e = (e << 5 | e >>> 27) + t << 0, r += (t ^ n & (e ^ t)) + i[6] - 1069501632, r = (r << 9 | r >>> 23) + e << 0, n += (e ^ t & (r ^ e)) + i[11] + 643717713, n = (n << 14 | n >>> 18) + r << 0, t += (r ^ e & (n ^ r)) + i[0] - 373897302, t = (t << 20 | t >>> 12) + n << 0, e += (n ^ r & (t ^ n)) + i[5] - 701558691, e = (e << 5 | e >>> 27) + t << 0, r += (t ^ n & (e ^ t)) + i[10] + 38016083, r = (r << 9 | r >>> 23) + e << 0, n += (e ^ t & (r ^ e)) + i[15] - 660478335, n = (n << 14 | n >>> 18) + r << 0, t += (r ^ e & (n ^ r)) + i[4] - 405537848, t = (t << 20 | t >>> 12) + n << 0, e += (n ^ r & (t ^ n)) + i[9] + 568446438, e = (e << 5 | e >>> 27) + t << 0, r += (t ^ n & (e ^ t)) + i[14] - 1019803690, r = (r << 9 | r >>> 23) + e << 0, n += (e ^ t & (r ^ e)) + i[3] - 187363961, n = (n << 14 | n >>> 18) + r << 0, t += (r ^ e & (n ^ r)) + i[8] + 1163531501, t = (t << 20 | t >>> 12) + n << 0, e += (n ^ r & (t ^ n)) + i[13] - 1444681467, e = (e << 5 | e >>> 27) + t << 0, r += (t ^ n & (e ^ t)) + i[2] - 51403784, r = (r << 9 | r >>> 23) + e << 0, n += (e ^ t & (r ^ e)) + i[7] + 1735328473, n = (n << 14 | n >>> 18) + r << 0, t += (r ^ e & (n ^ r)) + i[12] - 1926607734, t = (t << 20 | t >>> 12) + n << 0, o = t ^ n, e += (o ^ r) + i[5] - 378558, e = (e << 4 | e >>> 28) + t << 0, r += (o ^ e) + i[8] - 2022574463, r = (r << 11 | r >>> 21) + e << 0, u = r ^ e, n += (u ^ t) + i[11] + 1839030562, n = (n << 16 | n >>> 16) + r << 0, t += (u ^ n) + i[14] - 35309556, t = (t << 23 | t >>> 9) + n << 0, o = t ^ n, e += (o ^ r) + i[1] - 1530992060, e = (e << 4 | e >>> 28) + t << 0, r += (o ^ e) + i[4] + 1272893353, r = (r << 11 | r >>> 21) + e << 0, u = r ^ e, n += (u ^ t) + i[7] - 155497632, n = (n << 16 | n >>> 16) + r << 0, t += (u ^ n) + i[10] - 1094730640, t = (t << 23 | t >>> 9) + n << 0, o = t ^ n, e += (o ^ r) + i[13] + 681279174, e = (e << 4 | e >>> 28) + t << 0, r += (o ^ e) + i[0] - 358537222, r = (r << 11 | r >>> 21) + e << 0, u = r ^ e, n += (u ^ t) + i[3] - 722521979, n = (n << 16 | n >>> 16) + r << 0, t += (u ^ n) + i[6] + 76029189, t = (t << 23 | t >>> 9) + n << 0, o = t ^ n, e += (o ^ r) + i[9] - 640364487, e = (e << 4 | e >>> 28) + t << 0, r += (o ^ e) + i[12] - 421815835, r = (r << 11 | r >>> 21) + e << 0, u = r ^ e, n += (u ^ t) + i[15] + 530742520, n = (n << 16 | n >>> 16) + r << 0, t += (u ^ n) + i[2] - 995338651, t = (t << 23 | t >>> 9) + n << 0, e += (n ^ (t | ~r)) + i[0] - 198630844, e = (e << 6 | e >>> 26) + t << 0, r += (t ^ (e | ~n)) + i[7] + 1126891415, r = (r << 10 | r >>> 22) + e << 0, n += (e ^ (r | ~t)) + i[14] - 1416354905, n = (n << 15 | n >>> 17) + r << 0, t += (r ^ (n | ~e)) + i[5] - 57434055, t = (t << 21 | t >>> 11) + n << 0, e += (n ^ (t | ~r)) + i[12] + 1700485571, e = (e << 6 | e >>> 26) + t << 0, r += (t ^ (e | ~n)) + i[3] - 1894986606, r = (r << 10 | r >>> 22) + e << 0, n += (e ^ (r | ~t)) + i[10] - 1051523, n = (n << 15 | n >>> 17) + r << 0, t += (r ^ (n | ~e)) + i[1] - 2054922799, t = (t << 21 | t >>> 11) + n << 0, e += (n ^ (t | ~r)) + i[8] + 1873313359, e = (e << 6 | e >>> 26) + t << 0, r += (t ^ (e | ~n)) + i[15] - 30611744, r = (r << 10 | r >>> 22) + e << 0, n += (e ^ (r | ~t)) + i[6] - 1560198380, n = (n << 15 | n >>> 17) + r << 0, t += (r ^ (n | ~e)) + i[13] + 1309151649, t = (t << 21 | t >>> 11) + n << 0, e += (n ^ (t | ~r)) + i[4] - 145523070, e = (e << 6 | e >>> 26) + t << 0, r += (t ^ (e | ~n)) + i[11] - 1120210379, r = (r << 10 | r >>> 22) + e << 0, n += (e ^ (r | ~t)) + i[2] + 718787259, n = (n << 15 | n >>> 17) + r << 0, t += (r ^ (n | ~e)) + i[9] - 343485551, t = (t << 21 | t >>> 11) + n << 0, this.first ? (this.h0 = e + 1732584193 << 0, this.h1 = t - 271733879 << 0, this.h2 = n - 1732584194 << 0, this.h3 = r + 271733878 << 0, this.first = !1) : (this.h0 = this.h0 + e << 0, this.h1 = this.h1 + t << 0, this.h2 = this.h2 + n << 0, this.h3 = this.h3 + r << 0);
    }, $t.prototype.hex = function () {
      this.finalize();
      let e = this.h0,
          t = this.h1,
          n = this.h2,
          r = this.h3;
      return jt[e >> 4 & 15] + jt[15 & e] + jt[e >> 12 & 15] + jt[e >> 8 & 15] + jt[e >> 20 & 15] + jt[e >> 16 & 15] + jt[e >> 28 & 15] + jt[e >> 24 & 15] + jt[t >> 4 & 15] + jt[15 & t] + jt[t >> 12 & 15] + jt[t >> 8 & 15] + jt[t >> 20 & 15] + jt[t >> 16 & 15] + jt[t >> 28 & 15] + jt[t >> 24 & 15] + jt[n >> 4 & 15] + jt[15 & n] + jt[n >> 12 & 15] + jt[n >> 8 & 15] + jt[n >> 20 & 15] + jt[n >> 16 & 15] + jt[n >> 28 & 15] + jt[n >> 24 & 15] + jt[r >> 4 & 15] + jt[15 & r] + jt[r >> 12 & 15] + jt[r >> 8 & 15] + jt[r >> 20 & 15] + jt[r >> 16 & 15] + jt[r >> 28 & 15] + jt[r >> 24 & 15];
    };

    var Et = e => new $t().update(e).hex();

    function xt(e) {
      const t = typeof e;
      return null != e && ("object" === t || "function" === t);
    }

    function Mt(e, t, n) {
      if ("undefined" == typeof window) return;
      let r,
          o,
          u,
          i,
          c,
          a,
          s = 0,
          f = !1,
          l = !1,
          d = !0;
      const h = !t && 0 !== t && "function" == typeof requestAnimationFrame;
      if ("function" != typeof e) throw new TypeError("Expected a function");

      function p(t) {
        const n = r,
              u = o;
        return r = o = void 0, s = t, i = e.apply(u, n), i;
      }

      function y(e, t) {
        return h ? (cancelAnimationFrame(c), requestAnimationFrame(e)) : setTimeout(e, t);
      }

      function g(e) {
        const n = e - a;
        return void 0 === a || n >= t || n < 0 || l && e - s >= u;
      }

      function m() {
        const e = Date.now();
        if (g(e)) return v(e);
        c = y(m, function (e) {
          const n = e - s,
                r = t - (e - a);
          return l ? Math.min(r, u - n) : r;
        }(e));
      }

      function v(e) {
        return c = void 0, d && r ? p(e) : (r = o = void 0, i);
      }

      function b(...e) {
        const n = Date.now(),
              u = g(n);

        if (r = e, o = this, a = n, u) {
          if (void 0 === c) return function (e) {
            return s = e, c = y(m, t), f ? p(e) : i;
          }(a);
          if (l) return c = y(m, t), p(a);
        }

        return void 0 === c && (c = y(m, t)), i;
      }

      return t = +t || 0, xt(n) && (f = !!n.leading, l = "maxWait" in n, u = l ? Math.max(+n.maxWait || 0, t) : u, d = "trailing" in n ? !!n.trailing : d), b.cancel = function () {
        void 0 !== c && function (e) {
          if (h) return cancelAnimationFrame(e);
          clearTimeout(e);
        }(c), s = 0, r = a = o = c = void 0;
      }, b.flush = function () {
        return void 0 === c ? i : v(Date.now());
      }, b.pending = function () {
        return void 0 !== c;
      }, b;
    }

    e.YC = Re, e.YL = Ue, e.YR = {
      email: /\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*/,
      phone: /^1[3|4|5|6|7|8][0-9]{9}$/,
      fixedPhone: /(^0\d{2,3}-\d{7,8}$)|(^1[3|4|5|6|7|8][0-9]{9}$)/,
      qq: /[1-9][0-9]{4,}/,
      zipcode: /[1-9]\d{5}(?!\d)/,
      IDCard: /^\d{17}[\d|X|x]|\d{15}$/,
      chinese: /^[\u0391-\uFFE5]+$/,
      chineseNumberLine: /^[\u4E00-\u9FA5A-Za-z0-9_]+$/,
      chineseNumberNoLine: /^[\u4E00-\u9FA5A-Za-z0-9]+$/,
      integerZ: /^[1-9]\d*$/,
      integerF: /^-[1-9]\d*$/,
      number: /^\d+(\.\d+)?$/,
      numberNoMoreThan1: /^\-?([0-9](\d+)?(\.\d{1,1})?$)|(^0$)|(^\d\.\d{1,1})$/,
      numberNoMoreThan2: /^\-?([0-9](\d+)?(\.\d{1,2})?$)|(^0$)|(^\d\.\d{1,2})$/,
      numberNoMoreThan3: /^\-?([0-9](\d+)?(\.\d{1,3})?$)|(^0$)|(^\d\.\d{1,3})$/,
      numberNoMoreThan4: /^\-?([0-9](\d+)?(\.\d{1,4})?$)|(^0$)|(^\d\.\d{1,4})$/,
      greaterZero1: /^(0|[1-9]\d*)(\.\d{1,1})?$/,
      greaterZero2: /^(0|[1-9]\d*)(\.\d{1,2})?$/,
      greaterZero3: /^(0|[1-9]\d*)(\.\d{1,3})?$/,
      greaterZero4: /^(0|[1-9]\d*)(\.\d{1,4})?$/,
      zeroTo100: /^((\d|[1-9]\d)(\.\d{1,2})?$)|(^100|100.0|100.00$)$/,
      zeroTo1000: /^((\d|[1-9]{1,2}\d)(\.\d{1,2})?$)|(^1000|1000.0|1000.00$)$/
    }, e.YS = Fe, e.dateFormat = (e, t) => {
      if (!ze(e)) return null;
      let n;
      isNaN(e) || (e = Number(e)), n = new Date(e);
      const r = {
        YYYY: n.getFullYear(),
        YY: `${n.getFullYear()}`.slice(-2),
        MM: `0${n.getMonth() + 1}`.slice(-2),
        M: n.getMonth() + 1,
        DD: `0${n.getDate()}`.slice(-2),
        D: n.getDate(),
        HH: `0${n.getHours()}`.slice(-2),
        H: n.getHours(),
        hh: ("0" + n.getHours() % 12).slice(-2),
        h: n.getHours() % 12,
        mm: `0${n.getMinutes()}`.slice(-2),
        m: n.getMinutes(),
        ss: `0${n.getSeconds()}`.slice(-2),
        s: n.getSeconds(),
        w: ["日", "一", "二", "三", "四", "五", "六"][n.getDay()]
      };

      for (const e in r) t = t.replace(e, r[e]);

      return t;
    }, e.debounce = Mt, e.expandMultiple = (e, t, n) => at(e)(t, n), e.exportExcel = (e, t = {}) => {
      let n;

      if ("undefined" != typeof window) {
        n = window.localStorage.getItem("token");
        const r = Object.assign(Object.assign({}, t), {
          token: n
        });
        /^https.*/.test(e) || (e = e.replace("http", "https"));
        const o = `${e}?${(e => {
          const t = [];
          return Object.keys(e).forEach(n => {
            $e(e[n]) || z(e[n]) || t.push(`${n}=${e[n]}`);
          }), t.join("&");
        })(r)}`;
        console.log("YWFE下载地址=>", o);
        const u = `alink_${new Date().getTime()}`,
              i = document.createElement("a");
        i.setAttribute("href", o), i.setAttribute("target", "_blank"), i.setAttribute("id", u), document.getElementById(u) || document.body.appendChild(i), i.click(), setTimeout(() => {
          document.body.removeChild(i);
        }, 0);
      }
    }, e.fenToyuan = (e, t) => st(100)(e, t), e.gTokg = (e, t) => st(1e3)(e, t), e.getBiteLen = e => {
      if ("string" != typeof e) return 0;
      let t = 0;

      for (let n = 0; n < e.length; n++) e.charCodeAt(n) > 127 || 94 === e.charCodeAt(n) ? t += 2 : t += 1;

      return t;
    }, e.getEnv = He, e.getHost = (e, t) => {
      const n = window.configs ? window.configs : {};
      let r = He();
      return {
        basePath: n[e] ? n[e][r].API_BASE_URL + "" + ("mock" === r ? "/" + t : "") : "",
        loginPath: n.AUTH ? n.AUTH[r].APPLICATION_URL : ""
      };
    }, e.getMD5 = e => $e(e) || z(e) ? e : Ne(String, e) ? Et(e) : e, e.getQueries = e => {
      let t = e || window.location.search;
      return t = t.replace("?", ""), Ve(t) || {};
    }, e.getQuery = (e, t) => {
      const n = new RegExp(`(\\?|&)${e}=([^&]*)(&|$)`, "i");
      let r = window.location.search;
      $e(r) && (r = window.location.href);
      const o = n.exec((t || r).substr(1));
      return null != o && unescape(o[2]) || "";
    }, e.getQueryOfNextPageContext = e => {
      if (!e) return {};
      const {
        pathname: t = "",
        asPath: n = "",
        query: r
      } = e,
            o = K(ke("/"), de(e => /\[\w+\]/.test(e)), P(e => Te("]", "", Te("[", "", e))))(t),
            u = K(ke("#"), X(0, 1))(n) || [],
            i = u.length ? K(ke("/"), de(e => "" !== e))(u[0]) : [],
            c = o.map((e, t) => ({
        [`${e}`]: i[t]
      }));
      let a = {};
      return o.length ? a = Ee(c) || {} : a.path = i[0] || "desktop", Object.assign(Object.assign({}, r), a);
    }, e.getRoutes = (e, t, n, r) => {
      if ($e(e) || $e(t)) return {
        menus: [],
        defaultSelectedMenus: [],
        defaultOpenMenus: [],
        defaultMenu: {},
        permissions: []
      };
      let o;
      o = "/" !== r && "/undefined" !== r && "/null" !== r ? Ie("/", r) : [];
      let u = [],
          i = [],
          c = {};

      const a = e => {
        const r = t[e.url];
        if (!r) return {};
        const o = 0 === e.url.indexOf("/") ? e.url || "" : `/${e.url}`,
              a = {
          path: o,
          param: r.param || "",
          url: r.url,
          name: e.resourceId,
          meta: {
            title: e.name,
            icon: r.icon
          },
          component: r.component,
          hidden: r.hidden,
          origion_url: o
        };
        return ((null == n ? void 0 : n.primaryDefaultMenu) && e.url === (null == n ? void 0 : n.primaryDefaultMenu) || (null == n ? void 0 : n.secondaryDefaultMenu) && e.url === (null == n ? void 0 : n.secondaryDefaultMenu)) && (u = [e.resourceParentId], i = [e.resourceId], c = a), a;
      },
            s = [];

      let f = [];

      if (e.map(e => {
        const n = [],
              r = t[e.url],
              o = Be({
          key: "resourceType",
          value: "BUTTON"
        }, "childMenus", e);

        if (o && o.length) {
          const e = K(P(U("url")))(o);
          f = ge(f, e);
        }

        if (e.childMenus && e.childMenus.length) {
          Be({
            key: "resourceId"
          }, "childMenus", e.childMenus).map(e => {
            if (e) {
              const t = a(e);
              t && t.name && n.push(t);
            }
          });
        }

        const u = a(e);
        r && s.push(Object.assign(Object.assign({}, u), {
          children: n
        }));
      }), o.length && s.length) {
        const e = Le(o, s);
        i = e.defaultSelectedMenus, u = e.defaultOpenMenus, c = e.defaultMenu;
      } else if (!i.length || !u.length || !c) {
        const e = Ye(s);
        i = e.defaultSelectedMenus, u = e.defaultOpenMenus, c = e.defaultMenu;
      }

      return {
        menus: s,
        defaultSelectedMenus: i,
        defaultOpenMenus: u,
        defaultMenu: c,
        permissions: f
      };
    }, e.humpToLine = function (e) {
      return "string" != typeof e ? e : e.replace(/([A-Z])/g, "_$1").toLowerCase();
    }, e.isChinaMobile = e => /^((\+86)|(86)|(086))?(13[0-9]|15[0-9]|166|17[0-9]|18[0-9]|14[0-9]|19[0-9])[0-9]{8}$/.test(String(e)), e.isDate = ze, e.isURL = e => /^((?:(?:https?|ftp):|)\/\/)(?:\S+(?::\S*)?@)?(?:(?!(?:10|127)(?:\.\d{1,3}){3})(?!(?:169\.254|192\.168)(?:\.\d{1,3}){2})(?!172\.(?:1[6-9]|2\d|3[0-1])(?:\.\d{1,3}){2})(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))|(?:(?:[a-z\u00a1-\uffff0-9]-*)*[a-z\u00a1-\uffff0-9]+)(?:\.(?:[a-z\u00a1-\uffff0-9]-*)*[a-z\u00a1-\uffff0-9]+)*(?:\.(?:[a-z\u00a1-\uffff]{2,}))\.?)(?::\d{2,5})?(?:[/?#]\S*)?$/i.test(String(e)), e.joinPath = e => {
      if (!e || $e(e)) return "";
      const t = Object.keys(e);
      let n = "";
      return t.map(t => {
        e[t] && "search" !== t && (n += `/${e[t]}`), "search" === t && (n += e[t]);
      }), n;
    }, e.kgTog = (e, t) => at(1e3)(e, t), e.lineToHump = function (e) {
      return "string" != typeof e ? e : e.replace(/\_(\w)/g, function (e, t) {
        return t.toUpperCase();
      });
    }, e.loadScript = function (e, t, n) {
      return new Promise((r, o) => {
        const u = document.createElement("script");
        var i, c;
        u.id = t, u.readyState ? (c = () => r(u), (i = u).onreadystatechange = function () {
          "loaded" !== i.readyState && "complete" !== i.readyState || (i.onreadystatechange = null, c());
        }) : function (e, t, n) {
          qe(e, "load", t), qe(e, "error", n);
        }(u, () => r(u), () => {
          o(), document.removeChild(document.getElementById(t));
        }), n && _e.forEach(e => {
          if (e in n) {
            const t = n[e];
            "string" == typeof t ? u.setAttribute(e, t) : "boolean" == typeof t && (u[e] = t);
          }
        }), u.src = e.js, document.body.appendChild(u);
      });
    }, e.maxSubstrWord = (e, t = 5, n = !0) => "string" == typeof e ? n ? `${e.substr(0, t)}...` : e.substr(0, t) : e, e.numberToThousand = (e, t = ",") => $e(e) || z(e) ? e : isNaN(Number(e)) ? NaN : e.toString().replace(/\d+/, e => e.replace(/(\d)(?=(\d{3})+$)/g, e => `${e}${t}`)), e.parseParams = e => _(e).join("/"), e.pickAll = (e, t, n) => {
      const r = {
        reduce: H((n, o, u) => {
          const i = n(o, u);

          if (!(e => Ae([t], e))(u)) {
            return i && i.length ? P(t => t[e] || t)(i) : [];
          }

          return u[t] ? u[t].reduce(r.reduce(n), i) : i;
        }),
        find: H((e, t, n) => K(P(r.reduce(e, t)), we)(n))
      },
            o = (n, r) => r[e] ? n.concat([xe([t], r)]) : n;

      switch (Z(n)) {
        case "Object":
          return r.reduce(o, [])(n);

        case "Array":
          return r.find(o, [])(n);

        default:
          return n;
      }
    }, e.querystring = Ze, e.reduceMultiple = (e, t, n) => st(e)(t, n), e.reduceParams = e => {
      if (!e) return {};
      if (e instanceof FormData) return e;
      return de(e => !z(e) && !$e(e))(e) || {};
    }, e.remove = function (e, t) {
      const n = [];
      if (!e || !e.length) return n;
      let r = -1,
          o = [],
          u = e.length;

      for (; ++r < u;) {
        const u = e[r];
        t(u, r, e) && (n.push(u), o.push(r));
      }

      return function (e, t) {
        let n = e ? t.length : 0,
            r = n - 1,
            o = 0;

        for (; n--;) {
          const u = t[n];
          n != r && u === o || (o = u, Array.prototype.splice.call(e, u, 1));
        }
      }(e, o), n;
    }, e.slicePath = (e, t = 0, n) => {
      const r = Ie("/", e);
      n || (n = r.length - 1);
      return "/" + r.slice(t, n).join("/");
    }, e.split = Ie, e.sum = (e, t) => {
      let n = new it(0);

      const r = (e, t) => {
        "array" === ft(e) && Array.isArray(e) && e.forEach(e => {
          isNaN(e) || (n = n.plus(Number(e))), "object" === ft(e) && void 0 !== t && null !== e[t] && (n = n.plus(Number(e[t]))), "array" === ft(e) && Array.isArray(e) && r(e, t);
        });
      };

      return r(e, t), Number(n);
    }, e.throttle = function (e, t, n) {
      let r = !0,
          o = !0;
      if ("function" != typeof e) throw new TypeError("Expected a function");
      return xt(n) && (r = "leading" in n ? !!n.leading : r, o = "trailing" in n ? !!n.trailing : o), Mt(e, t, {
        leading: r,
        trailing: o,
        maxWait: t
      });
    }, e.toDate = e => ze(e) ? new Date(e).getTime() : 0, e.translateMapToArray = e => {
      let t = [];

      for (const [n, r] of e.entries()) t.push({
        label: r,
        value: n
      });

      return t;
    }, e.treeFind = (e, t, n) => {
      const r = {
        reduce: H((n, o, i) => {
          const c = n(o, i);
          return ((e => t && Ae([t], e) && !$e(e[t]))(i) || i[e.key] !== e.value) && t && i[t] && !$e(i[t]) ? r.reduce(u, [])(i[t]) : c;
        }),
        find: H((e, t, n) => K(P(r.reduce(e, t)), we)(n))
      },
            o = (n, r) => e.value && r[e.key] && r[e.key] === e.value || !e.value && r[e.key] ? t ? n.concat([xe([t], r)]) : n.concat([r]) : n,
            u = (e, t) => {
        const n = Object.keys(t),
              u = [];
        return n.map(e => {
          u.push(t[e]);
        }), r.find(o, e)(u);
      };

      switch (Z(n)) {
        case "Object":
          return r.reduce(u, [])(n);

        case "Array":
          return r.find(o, [])(n);

        default:
          return [];
      }
    }, e.treePaths = (e, t, n) => {
      const r = {
        reduce: H((n, o, i, c) => {
          const a = n(o, i, c);
          return (e => Ae([t], e) && !$e(e[t]))(c) || c[e.key] !== e.value ? c[t] && !$e(c[t]) ? r.reduce(u, [], xe([t], c))(c[t]) : a : (i.path && a.splice(0, 0, i.path), a);
        }),
        find: H((e, t, n, o) => K(P(r.reduce(e, t, n)), we)(o))
      },
            o = (t, n, r) => e.value && r[e.key] && r[e.key] === e.value || !e.value && r[e.key] ? t.concat([r.path]) : t,
            u = (e, t, n) => {
        if (!n || $e(n)) return e;
        const u = Object.keys(n),
              i = [];
        return u.map(e => {
          i.push(n[e]);
        }), r.find(o, e, t)(i);
      };

      switch (Z(n)) {
        case "Object":
          return r.reduce(u, [], {})(n);

        case "Array":
          return r.find(o, [], {})(n);

        default:
          return [];
      }
    }, e.treeReduce = Be, e.trimAll = Ce, e.trimParams = lt, e.unLoadScript = function (e) {
      if (document.getElementById(e)) {
        const t = document.getElementById(e);
        document.body.removeChild(t);
      }
    }, e.uuidv4 = () => bt(), e.wanToyuan = (e, t) => at(1e4)(e, t), e.yuanTofen = (e, t) => at(100)(e, t), e.yuanTowan = (e, t) => st(1e4)(e, t), Object.defineProperty(e, "__esModule", {
      value: !0
    });
  });
})(ywfeUtils_umd, ywfeUtils_umd.exports);

const USER_UNLOGIN = 17020001;
const USER_TOKEN_INVALID = 17020002;
const USER_TOKEN_NULL = 17020003;
const TOKEN_FAIL_OLD_1 = -2;
const TOKEN_FAIL_OLD_2 = 1000;
const BIZ_MODULE_NOTFOUND = 17031000;
const GO_TO_LOGIN = [
    USER_UNLOGIN,
    USER_TOKEN_INVALID,
    USER_TOKEN_NULL,
    TOKEN_FAIL_OLD_1,
    TOKEN_FAIL_OLD_2,
];
const NO_MESSAGE = [BIZ_MODULE_NOTFOUND];

const instance = axios.create({
    timeout: 30 * 1000,
});
instance.interceptors.request.use(config => {
    const configData = config;
    if (typeof window !== 'undefined') {
        const token = localStorage.getItem('token') || '';
        configData.headers = Object.assign(Object.assign({}, configData.headers), { 'X-TOKEN': token });
    }
    return configData;
}, error => {
    return Promise.reject(error);
});
instance.interceptors.response.use((res) => {
    const { data, config } = res;
    const { success, code } = data;
    const isFormData = typeof data === 'string';
    const isArraybuffer = res.config.responseType === 'arraybuffer';
    if (isFormData || isArraybuffer) {
        if (data) {
            return data;
        }
        else {
            if (typeof window !== 'undefined') {
                message.error(isFormData ? '图片上传失败' : '下载失败');
            }
            return Promise.reject();
        }
    }
    if (success) {
        return data.data || success;
    }
    else {
        if (GO_TO_LOGIN.indexOf(Number(code)) >= 0 &&
            typeof window !== 'undefined') {
            const projectId = window.localStorage.getItem('projectId');
            const { loginHost = '' } = config;
            let pathname = window.location.pathname;
            let search = window.location.search;
            search = search.replace('?', '');
            let query = ywfeUtils_umd.exports.querystring.parse(search);
            query = Object.assign(Object.assign({}, query), { projectId: projectId || query.projectId });
            let loginHostNew = loginHost;
            // 针对电虎独立站の登录跳转(勿删！！！)
            if (window.location.host === 'dianhu.ywwl.com') {
                loginHostNew = `${window.location.protocol}//yun.ywwl.com`;
            }
            else if (window.location.host == 'dianhu-test.ywwl.com') {
                loginHostNew = `${window.location.protocol}//yun-test.ywwl.com`;
            }
            else if (window.location.host == 'dianhu-dev.ywwl.com') {
                loginHostNew = `${window.location.protocol}//yun-dev.ywwl.com`;
            }
            window.top.location.href = `${loginHostNew}/login?${ywfeUtils_umd.exports.querystring.stringify(query)}&pathname=${encodeURIComponent(pathname)}&targetUrl=${encodeURIComponent(window.location.pathname + window.location.search)}`;
        }
        if (typeof window !== 'undefined' && NO_MESSAGE.indexOf(code) < 0) {
            message.error(data.msg || data.message);
        }
        return Promise.reject(data);
    }
}, (error) => {
    if (typeof window !== 'undefined') {
        message.error('网络繁忙, 休息一会儿再来吧~ ^_^！');
    }
    return Promise.reject(error);
});
class Request {
    static get(url, config) {
        return instance.get(url, config);
    }
    static post(url, data, config) {
        return instance.post(url, data, config);
    }
}

export default Request;
//# sourceMappingURL=ywfe-request.esm.js.map
