import axios, { AxiosResponse, AxiosRequestConfig } from 'axios';
import { message } from 'antd';
import { querystring as qs } from '@ywfe/utils';
import { GO_TO_LOGIN, NO_MESSAGE } from './constants';

export interface YWRequestConfig extends AxiosRequestConfig {
  loginHost?: string;
}

export interface YWResponse extends AxiosResponse {
  config: YWRequestConfig;
}

const instance = axios.create({
  timeout: 30 * 1000,
});

instance.interceptors.request.use(
  config => {
    const configData = config;
    if (typeof window !== 'undefined') {
      const token = localStorage.getItem('token') || '';
      configData.headers = {
        ...configData.headers,
        'X-TOKEN': token,
      };
    }
    return configData;
  },
  error => {
    return Promise.reject(error);
  },
);

instance.interceptors.response.use(
  (res: YWResponse): any => {
    const { data, config } = res;
    const { success, code } = data;
    const isFormData = typeof data === 'string';
    const isArraybuffer = res.config.responseType === 'arraybuffer';
    if (isFormData || isArraybuffer) {
      if (data) {
        return data;
      } else {
        if (typeof window !== 'undefined') {
          message.error(isFormData ? '图片上传失败' : '下载失败');
        }

        return Promise.reject();
      }
    }
    if (success) {
      return data.data || success;
    } else {
      if (
        GO_TO_LOGIN.indexOf(Number(code)) >= 0 &&
        typeof window !== 'undefined'
      ) {
        const projectId = window.localStorage.getItem('projectId');
        const { loginHost = '' } = config;
        let pathname = window.location.pathname;
        let search = window.location.search;
        search = search.replace('?', '');
        let query: any = qs.parse(search);
        query = {
          ...query,
          projectId: projectId || query.projectId,
        };

        let loginHostNew = loginHost
        // 针对电虎独立站の登录跳转(勿删！！！)
        if (window.location.host === 'dianhu.ywwl.com') {
          loginHostNew = `${window.location.protocol}//yun.ywwl.com`
        } else if (window.location.host == 'dianhu-test.ywwl.com') {
          loginHostNew = `${window.location.protocol}//yun-test.ywwl.com`
        } else if (window.location.host == 'dianhu-dev.ywwl.com') {
          loginHostNew = `${window.location.protocol}//yun-dev.ywwl.com`
        }

        window.top.location.href = `${loginHostNew}/login?${qs.stringify(
          query,
        )}&pathname=${encodeURIComponent(pathname)}&targetUrl=${encodeURIComponent(window.location.pathname + window.location.search)}`;
      }
      if (typeof window !== 'undefined' && NO_MESSAGE.indexOf(code) < 0) {
        message.error(data.msg || data.message);
      }

      return Promise.reject(data);
    }
  },
  (error: any) => {
    if (typeof window !== 'undefined') {
      message.error('网络繁忙, 休息一会儿再来吧~ ^_^！');
    }

    return Promise.reject(error);
  },
);

export default class Request {
  static get<T>(url: string, config?: YWRequestConfig): Promise<T> {
    return instance.get(url, config);
  }

  static post<T>(
    url: string,
    data?: any,
    config?: YWRequestConfig,
  ): Promise<T> {
    return instance.post(url, data, config);
  }
}
